Class: Google::Apis::LoggingV2::Explicit
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::Explicit
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Specifies a set of buckets with arbitrary widths.There are size(bounds) + 1 (= N) buckets. Bucket i has the following boundaries:Upper bound (0 <= i < N-1): boundsi Lower bound (1 <= i < N); boundsi - 1The bounds field must contain at least one element. If bounds has only one element, then there are no finite buckets, and that single element is the common boundary of the overflow and underflow buckets.
Instance Attribute Summary collapse
-
#bounds ⇒ Array<Float>
The values must be monotonically increasing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Explicit
constructor
A new instance of Explicit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Explicit
Returns a new instance of Explicit.
793 794 795 |
# File 'lib/google/apis/logging_v2/classes.rb', line 793 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bounds ⇒ Array<Float>
The values must be monotonically increasing.
Corresponds to the JSON property bounds
791 792 793 |
# File 'lib/google/apis/logging_v2/classes.rb', line 791 def bounds @bounds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
798 799 800 |
# File 'lib/google/apis/logging_v2/classes.rb', line 798 def update!(**args) @bounds = args[:bounds] if args.key?(:bounds) end |