Class: Google::Apis::LoggingV2::Exponential

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Specifies an exponential sequence of buckets that have a width that is proportional to the value of the lower bound. Each bucket represents a constant relative uncertainty on a specific value in the bucket.There are num_finite_buckets + 2 (= N) buckets. Bucket i has the following boundaries: Upper bound (0 <= i < N-1): scale * (growth_factor ^ i).Lower bound (1 <= i < N): scale * (growth_factor ^ (i - 1)).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Exponential

Returns a new instance of Exponential.



827
828
829
# File 'lib/google/apis/logging_v2/classes.rb', line 827

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#growth_factorFloat

Must be greater than 1. Corresponds to the JSON property growthFactor

Returns:

  • (Float)


815
816
817
# File 'lib/google/apis/logging_v2/classes.rb', line 815

def growth_factor
  @growth_factor
end

#num_finite_bucketsFixnum

Must be greater than 0. Corresponds to the JSON property numFiniteBuckets

Returns:

  • (Fixnum)


820
821
822
# File 'lib/google/apis/logging_v2/classes.rb', line 820

def num_finite_buckets
  @num_finite_buckets
end

#scaleFloat

Must be greater than 0. Corresponds to the JSON property scale

Returns:

  • (Float)


825
826
827
# File 'lib/google/apis/logging_v2/classes.rb', line 825

def scale
  @scale
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



832
833
834
835
836
# File 'lib/google/apis/logging_v2/classes.rb', line 832

def update!(**args)
  @growth_factor = args[:growth_factor] if args.key?(:growth_factor)
  @num_finite_buckets = args[:num_finite_buckets] if args.key?(:num_finite_buckets)
  @scale = args[:scale] if args.key?(:scale)
end