Class: Google::Apis::LoggingV2::Link

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Describes a link connected to an analytics enabled bucket.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Link

Returns a new instance of Link.



1200
1201
1202
# File 'lib/google/apis/logging_v2/classes.rb', line 1200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_datasetGoogle::Apis::LoggingV2::BigQueryDataset

Describes a BigQuery dataset that was created by a link. Corresponds to the JSON property bigqueryDataset



1169
1170
1171
# File 'lib/google/apis/logging_v2/classes.rb', line 1169

def bigquery_dataset
  @bigquery_dataset
end

#create_timeString

Output only. The creation timestamp of the link. Corresponds to the JSON property createTime

Returns:

  • (String)


1174
1175
1176
# File 'lib/google/apis/logging_v2/classes.rb', line 1174

def create_time
  @create_time
end

#descriptionString

Optional. Describes this link.The maximum length of the description is 8000 characters. Corresponds to the JSON property description

Returns:

  • (String)


1180
1181
1182
# File 'lib/google/apis/logging_v2/classes.rb', line 1180

def description
  @description
end

#lifecycle_stateString

Output only. The resource lifecycle state. Corresponds to the JSON property lifecycleState

Returns:

  • (String)


1185
1186
1187
# File 'lib/google/apis/logging_v2/classes.rb', line 1185

def lifecycle_state
  @lifecycle_state
end

#nameString

Output only. The resource name of the link. The name can have up to 100 characters. A valid link id (at the end of the link name) must only have alphanumeric characters and underscores within it. "projects/[PROJECT_ID]/ locations/[LOCATION_ID]/buckets/[BUCKET_ID]/links/[LINK_ID]" "organizations/[ ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/links/[LINK_ID]" " billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]/buckets/[ BUCKET_ID]/links/[LINK_ID]" "folders/[FOLDER_ID]/locations/[LOCATION_ID]/ buckets/[BUCKET_ID]/links/[LINK_ID]" For example:projects/my-project/ locations/global/buckets/my-bucket/links/my_link Corresponds to the JSON propertyname`

Returns:

  • (String)


1198
1199
1200
# File 'lib/google/apis/logging_v2/classes.rb', line 1198

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1205
1206
1207
1208
1209
1210
1211
# File 'lib/google/apis/logging_v2/classes.rb', line 1205

def update!(**args)
  @bigquery_dataset = args[:bigquery_dataset] if args.key?(:bigquery_dataset)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state)
  @name = args[:name] if args.key?(:name)
end