Class: Google::Apis::LoggingV2::ListLinksResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

The response from ListLinks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListLinksResponse

Returns a new instance of ListLinksResponse.



1539
1540
1541
# File 'lib/google/apis/logging_v2/classes.rb', line 1539

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

A list of links. Corresponds to the JSON property links

Returns:



1530
1531
1532
# File 'lib/google/apis/logging_v2/classes.rb', line 1530

def links
  @links
end

#next_page_tokenString

If there might be more results than those appearing in this response, then nextPageToken is included. To get the next set of results, call the same method again using the value of nextPageToken as pageToken. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1537
1538
1539
# File 'lib/google/apis/logging_v2/classes.rb', line 1537

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1544
1545
1546
1547
# File 'lib/google/apis/logging_v2/classes.rb', line 1544

def update!(**args)
  @links = args[:links] if args.key?(:links)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end