Class: Google::Apis::LoggingV2::ListLogEntriesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Result returned from ListLogEntries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListLogEntriesResponse

Returns a new instance of ListLogEntriesResponse.



1474
1475
1476
# File 'lib/google/apis/logging_v2/classes.rb', line 1474

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entriesArray<Google::Apis::LoggingV2::LogEntry>

A list of log entries. If entries is empty, nextPageToken may still be returned, indicating that more entries may exist. See nextPageToken for more information. Corresponds to the JSON property entries



1459
1460
1461
# File 'lib/google/apis/logging_v2/classes.rb', line 1459

def entries
  @entries
end

#next_page_tokenString

If there might be more results than those appearing in this response, then nextPageToken is included. To get the next set of results, call this method again using the value of nextPageToken as pageToken.If a value for next_page_token appears and the entries field is empty, it means that the search found no log entries so far but it did not have time to search all the possible log entries. Retry the method with this value for page_token to continue the search. Alternatively, consider speeding up the search by changing your filter to specify a single log name or resource type, or to narrow the time range of the search. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1472
1473
1474
# File 'lib/google/apis/logging_v2/classes.rb', line 1472

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1479
1480
1481
1482
# File 'lib/google/apis/logging_v2/classes.rb', line 1479

def update!(**args)
  @entries = args[:entries] if args.key?(:entries)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end