Class: Google::Apis::LoggingV2::ListLogsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Result returned from ListLogs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListLogsResponse

Returns a new instance of ListLogsResponse.



1769
1770
1771
# File 'lib/google/apis/logging_v2/classes.rb', line 1769

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#log_namesArray<String>

A list of log names. For example, "projects/my-project/logs/syslog" or " organizations/123/logs/cloudresourcemanager.googleapis.com%2Factivity". Corresponds to the JSON property logNames

Returns:

  • (Array<String>)


1760
1761
1762
# File 'lib/google/apis/logging_v2/classes.rb', line 1760

def log_names
  @log_names
end

#next_page_tokenString

If there might be more results than those appearing in this response, then nextPageToken is included. To get the next set of results, call this method again using the value of nextPageToken as pageToken. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1767
1768
1769
# File 'lib/google/apis/logging_v2/classes.rb', line 1767

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1774
1775
1776
1777
# File 'lib/google/apis/logging_v2/classes.rb', line 1774

def update!(**args)
  @log_names = args[:log_names] if args.key?(:log_names)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end