Class: Google::Apis::LoggingV2::ListSinksResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Result returned from ListSinks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSinksResponse

Returns a new instance of ListSinksResponse.



1936
1937
1938
# File 'lib/google/apis/logging_v2/classes.rb', line 1936

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

If there might be more results than appear in this response, then nextPageToken is included. To get the next set of results, call the same method again using the value of nextPageToken as pageToken. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1929
1930
1931
# File 'lib/google/apis/logging_v2/classes.rb', line 1929

def next_page_token
  @next_page_token
end

#sinksArray<Google::Apis::LoggingV2::LogSink>

A list of sinks. Corresponds to the JSON property sinks



1934
1935
1936
# File 'lib/google/apis/logging_v2/classes.rb', line 1934

def sinks
  @sinks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1941
1942
1943
1944
# File 'lib/google/apis/logging_v2/classes.rb', line 1941

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @sinks = args[:sinks] if args.key?(:sinks)
end