Class: Google::Apis::LoggingV2::LogBucket

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Describes a repository in which log entries are stored.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LogBucket

Returns a new instance of LogBucket.



2122
2123
2124
# File 'lib/google/apis/logging_v2/classes.rb', line 2122

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analytics_enabledBoolean Also known as: analytics_enabled?

Optional. Whether log analytics is enabled for this bucket.Once enabled, log analytics features cannot be disabled. Corresponds to the JSON property analyticsEnabled

Returns:

  • (Boolean)


2050
2051
2052
# File 'lib/google/apis/logging_v2/classes.rb', line 2050

def analytics_enabled
  @analytics_enabled
end

#cmek_settingsGoogle::Apis::LoggingV2::CmekSettings

Describes the customer-managed encryption key (CMEK) settings associated with a project, folder, organization, billing account, or flexible resource.Note: CMEK for the Log Router can currently only be configured for Google Cloud organizations. Once configured, it applies to all projects and folders in the Google Cloud organization.See Configure CMEK for Cloud Logging (https://docs. cloud.google.com/logging/docs/routing/managed-encryption) for more information. Corresponds to the JSON property cmekSettings



2061
2062
2063
# File 'lib/google/apis/logging_v2/classes.rb', line 2061

def cmek_settings
  @cmek_settings
end

#create_timeString

Output only. The creation timestamp of the bucket. This is not set for any of the default buckets. Corresponds to the JSON property createTime

Returns:

  • (String)


2067
2068
2069
# File 'lib/google/apis/logging_v2/classes.rb', line 2067

def create_time
  @create_time
end

#descriptionString

Optional. Describes this bucket. Corresponds to the JSON property description

Returns:

  • (String)


2072
2073
2074
# File 'lib/google/apis/logging_v2/classes.rb', line 2072

def description
  @description
end

#index_configsArray<Google::Apis::LoggingV2::IndexConfig>

Optional. A list of indexed fields and related configuration data. Corresponds to the JSON property indexConfigs



2077
2078
2079
# File 'lib/google/apis/logging_v2/classes.rb', line 2077

def index_configs
  @index_configs
end

#lifecycle_stateString

Output only. The bucket lifecycle state. Corresponds to the JSON property lifecycleState

Returns:

  • (String)


2082
2083
2084
# File 'lib/google/apis/logging_v2/classes.rb', line 2082

def lifecycle_state
  @lifecycle_state
end

#lockedBoolean Also known as: locked?

Optional. Whether the bucket is locked.The retention period on a locked bucket cannot be changed. Locked buckets may only be deleted if they are empty. Corresponds to the JSON property locked

Returns:

  • (Boolean)


2088
2089
2090
# File 'lib/google/apis/logging_v2/classes.rb', line 2088

def locked
  @locked
end

#nameString

Output only. The resource name of the bucket.For example:projects/my-project/ locations/global/buckets/my-bucketFor a list of supported locations, see Supported Regions (https://docs.cloud.google.com/logging/docs/region-support) For the location of global it is unspecified where log entries are actually stored.After a bucket has been created, the location cannot be changed. Corresponds to the JSON property name

Returns:

  • (String)


2098
2099
2100
# File 'lib/google/apis/logging_v2/classes.rb', line 2098

def name
  @name
end

#restricted_fieldsArray<String>

Optional. Log entry field paths that are denied access in this bucket.The following fields and their children are eligible: textPayload, jsonPayload, protoPayload, httpRequest, labels, sourceLocation.Restricting a repeated field will restrict all values. Adding a parent will block all child fields. (e.g. foo.bar will block foo.bar.baz) Corresponds to the JSON property restrictedFields

Returns:

  • (Array<String>)


2107
2108
2109
# File 'lib/google/apis/logging_v2/classes.rb', line 2107

def restricted_fields
  @restricted_fields
end

#retention_daysFixnum

Optional. Logs will be retained by default for this amount of time, after which they will automatically be deleted. The minimum retention period is 1 day. If this value is set to zero at bucket creation time, the default time of 30 days will be used. Corresponds to the JSON property retentionDays

Returns:

  • (Fixnum)


2115
2116
2117
# File 'lib/google/apis/logging_v2/classes.rb', line 2115

def retention_days
  @retention_days
end

#update_timeString

Output only. The last update timestamp of the bucket. Corresponds to the JSON property updateTime

Returns:

  • (String)


2120
2121
2122
# File 'lib/google/apis/logging_v2/classes.rb', line 2120

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
# File 'lib/google/apis/logging_v2/classes.rb', line 2127

def update!(**args)
  @analytics_enabled = args[:analytics_enabled] if args.key?(:analytics_enabled)
  @cmek_settings = args[:cmek_settings] if args.key?(:cmek_settings)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @index_configs = args[:index_configs] if args.key?(:index_configs)
  @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state)
  @locked = args[:locked] if args.key?(:locked)
  @name = args[:name] if args.key?(:name)
  @restricted_fields = args[:restricted_fields] if args.key?(:restricted_fields)
  @retention_days = args[:retention_days] if args.key?(:retention_days)
  @update_time = args[:update_time] if args.key?(:update_time)
end