Class: Google::Apis::LoggingV2::LogEntryOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Additional information about a potentially long-running operation with which a log entry is associated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LogEntryOperation

Returns a new instance of LogEntryOperation.



2402
2403
2404
# File 'lib/google/apis/logging_v2/classes.rb', line 2402

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#firstBoolean Also known as: first?

Optional. Set this to True if this is the first log entry in the operation. Corresponds to the JSON property first

Returns:

  • (Boolean)


2380
2381
2382
# File 'lib/google/apis/logging_v2/classes.rb', line 2380

def first
  @first
end

#idString

Optional. An arbitrary operation identifier. Log entries with the same identifier are assumed to be part of the same operation. Corresponds to the JSON property id

Returns:

  • (String)


2387
2388
2389
# File 'lib/google/apis/logging_v2/classes.rb', line 2387

def id
  @id
end

#lastBoolean Also known as: last?

Optional. Set this to True if this is the last log entry in the operation. Corresponds to the JSON property last

Returns:

  • (Boolean)


2392
2393
2394
# File 'lib/google/apis/logging_v2/classes.rb', line 2392

def last
  @last
end

#producerString

Optional. An arbitrary producer identifier. The combination of id and producer must be globally unique. Examples for producer: "MyDivision.MyBigCompany.com", "github.com/MyProject/MyApplication". Corresponds to the JSON property producer

Returns:

  • (String)


2400
2401
2402
# File 'lib/google/apis/logging_v2/classes.rb', line 2400

def producer
  @producer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2407
2408
2409
2410
2411
2412
# File 'lib/google/apis/logging_v2/classes.rb', line 2407

def update!(**args)
  @first = args[:first] if args.key?(:first)
  @id = args[:id] if args.key?(:id)
  @last = args[:last] if args.key?(:last)
  @producer = args[:producer] if args.key?(:producer)
end