Class: Google::Apis::LoggingV2::LogErrorGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Contains metadata that associates the LogEntry to Error Reporting error groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LogErrorGroup

Returns a new instance of LogErrorGroup.



2487
2488
2489
# File 'lib/google/apis/logging_v2/classes.rb', line 2487

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The id is a unique identifier for a particular error group; it is the last part of the error group resource name: /project/[PROJECT_ID]/errors/[ ERROR_GROUP_ID]. Example: COShysOX0r_51QE.This field can be used to search for log entries belonging to a specific error group in Logs Explorer (e.g., error_groups.id = "ID") or Observability Analytics.The id is derived from key parts of the error-log content and is treated as Service Data. For information about how Service Data is handled, see Google Cloud Privacy Notice (https:// cloud.google.com/terms/cloud-privacy-notice). Corresponds to the JSON property id

Returns:

  • (String)


2485
2486
2487
# File 'lib/google/apis/logging_v2/classes.rb', line 2485

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2492
2493
2494
# File 'lib/google/apis/logging_v2/classes.rb', line 2492

def update!(**args)
  @id = args[:id] if args.key?(:id)
end