Class: Google::Apis::LoggingV2::LogExclusion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Specifies a set of log entries that are filtered out by a sink. If your Google Cloud resource receives a large volume of log entries, you can use exclusions to reduce your chargeable logs. Note that exclusions on organization-level and folder-level sinks don't apply to child resources. Note also that you cannot modify the _Required sink or exclude logs from it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LogExclusion

Returns a new instance of LogExclusion.



2548
2549
2550
# File 'lib/google/apis/logging_v2/classes.rb', line 2548

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The creation timestamp of the exclusion.This field may not be present for older exclusions. Corresponds to the JSON property createTime

Returns:

  • (String)


2509
2510
2511
# File 'lib/google/apis/logging_v2/classes.rb', line 2509

def create_time
  @create_time
end

#descriptionString

Optional. A description of this exclusion. Corresponds to the JSON property description

Returns:

  • (String)


2514
2515
2516
# File 'lib/google/apis/logging_v2/classes.rb', line 2514

def description
  @description
end

#disabledBoolean Also known as: disabled?

Optional. If set to True, then this exclusion is disabled and it does not exclude any log entries. You can update an exclusion to change the value of this field. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


2521
2522
2523
# File 'lib/google/apis/logging_v2/classes.rb', line 2521

def disabled
  @disabled
end

#filterString

Required. An advanced logs filter (https://docs.cloud.google.com/logging/docs/ view/building-queries#queries-by-expression) that matches the log entries to be excluded. By using the sample function (https://docs.cloud.google.com/ logging/docs/view/logging-query-language#sample), you can exclude less than 100% of the matching log entries.For example, the following query matches 99% of low-severity log entries from Google Cloud Storage buckets:resource.type= gcs_bucket severity<ERROR sample(insertId, 0.99) Corresponds to the JSON property filter

Returns:

  • (String)


2533
2534
2535
# File 'lib/google/apis/logging_v2/classes.rb', line 2533

def filter
  @filter
end

#nameString

Optional. A client-assigned identifier, such as "load-balancer-exclusion". Identifiers are limited to 100 characters and can include only letters, digits, underscores, hyphens, and periods. First character has to be alphanumeric. Corresponds to the JSON property name

Returns:

  • (String)


2540
2541
2542
# File 'lib/google/apis/logging_v2/classes.rb', line 2540

def name
  @name
end

#update_timeString

Output only. The last update timestamp of the exclusion.This field may not be present for older exclusions. Corresponds to the JSON property updateTime

Returns:

  • (String)


2546
2547
2548
# File 'lib/google/apis/logging_v2/classes.rb', line 2546

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2553
2554
2555
2556
2557
2558
2559
2560
# File 'lib/google/apis/logging_v2/classes.rb', line 2553

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @disabled = args[:disabled] if args.key?(:disabled)
  @filter = args[:filter] if args.key?(:filter)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end