Class: Google::Apis::LoggingV2::LogScope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Describes a group of resources to read log entries from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LogScope

Returns a new instance of LogScope.



2767
2768
2769
# File 'lib/google/apis/logging_v2/classes.rb', line 2767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The creation timestamp of the log scope. Corresponds to the JSON property createTime

Returns:

  • (String)


2738
2739
2740
# File 'lib/google/apis/logging_v2/classes.rb', line 2738

def create_time
  @create_time
end

#descriptionString

Optional. Describes this log scope.The maximum length of the description is 8000 characters. Corresponds to the JSON property description

Returns:

  • (String)


2744
2745
2746
# File 'lib/google/apis/logging_v2/classes.rb', line 2744

def description
  @description
end

#nameString

Output only. The resource name of the log scope.Log scopes are only available in the global location. For example:projects/my-project/locations/global/ logScopes/my-log-scope Corresponds to the JSON property name

Returns:

  • (String)


2751
2752
2753
# File 'lib/google/apis/logging_v2/classes.rb', line 2751

def name
  @name
end

#resource_namesArray<String>

Required. Names of one or more parent resources (organizations and folders are not supported.): projects/[PROJECT_ID]May alternatively be one or more views: projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[ VIEW_ID]A log scope can include a maximum of 5 projects and a maximum of 100 resources in total. Corresponds to the JSON property resourceNames

Returns:

  • (Array<String>)


2760
2761
2762
# File 'lib/google/apis/logging_v2/classes.rb', line 2760

def resource_names
  @resource_names
end

#update_timeString

Output only. The last update timestamp of the log scope. Corresponds to the JSON property updateTime

Returns:

  • (String)


2765
2766
2767
# File 'lib/google/apis/logging_v2/classes.rb', line 2765

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2772
2773
2774
2775
2776
2777
2778
# File 'lib/google/apis/logging_v2/classes.rb', line 2772

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @resource_names = args[:resource_names] if args.key?(:resource_names)
  @update_time = args[:update_time] if args.key?(:update_time)
end