Class: Google::Apis::LoggingV2::LogSplit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Additional information used to correlate multiple log entries. Used when a single LogEntry would exceed the Google Cloud Logging size limit and is split across multiple log entries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LogSplit

Returns a new instance of LogSplit.



2962
2963
2964
# File 'lib/google/apis/logging_v2/classes.rb', line 2962

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#indexFixnum

The index of this LogEntry in the sequence of split log entries. Log entries are given |index| values 0, 1, ..., n-1 for a sequence of n log entries. Corresponds to the JSON property index

Returns:

  • (Fixnum)


2948
2949
2950
# File 'lib/google/apis/logging_v2/classes.rb', line 2948

def index
  @index
end

#total_splitsFixnum

The total number of log entries that the original LogEntry was split into. Corresponds to the JSON property totalSplits

Returns:

  • (Fixnum)


2953
2954
2955
# File 'lib/google/apis/logging_v2/classes.rb', line 2953

def total_splits
  @total_splits
end

#uidString

A globally unique identifier for all log entries in a sequence of split log entries. All log entries with the same |LogSplit.uid| are assumed to be part of the same sequence of split log entries. Corresponds to the JSON property uid

Returns:

  • (String)


2960
2961
2962
# File 'lib/google/apis/logging_v2/classes.rb', line 2960

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2967
2968
2969
2970
2971
# File 'lib/google/apis/logging_v2/classes.rb', line 2967

def update!(**args)
  @index = args[:index] if args.key?(:index)
  @total_splits = args[:total_splits] if args.key?(:total_splits)
  @uid = args[:uid] if args.key?(:uid)
end