Class: Google::Apis::LoggingV2::LogView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Describes a view over log entries in a bucket.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LogView

Returns a new instance of LogView.



3022
3023
3024
# File 'lib/google/apis/logging_v2/classes.rb', line 3022

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The creation timestamp of the view. Corresponds to the JSON property createTime

Returns:

  • (String)


2992
2993
2994
# File 'lib/google/apis/logging_v2/classes.rb', line 2992

def create_time
  @create_time
end

#descriptionString

Optional. Describes this view. Corresponds to the JSON property description

Returns:

  • (String)


2997
2998
2999
# File 'lib/google/apis/logging_v2/classes.rb', line 2997

def description
  @description
end

#filterString

Optional. Filter that restricts which log entries in a bucket are visible in this view.Filters must be logical conjunctions that use the AND operator, and they can use any of the following qualifiers: SOURCE(), which specifies a project, folder, organization, or billing account of origin. resource.type, which specifies the resource type. LOG_ID(), which identifies the log.They can also use the negations of these qualifiers with the NOT operator.For example: SOURCE("projects/myproject") AND resource.type = "gce_instance" AND NOT LOG_ID( "stdout") Corresponds to the JSON property filter

Returns:

  • (String)


3009
3010
3011
# File 'lib/google/apis/logging_v2/classes.rb', line 3009

def filter
  @filter
end

#nameString

Output only. The resource name of the view.For example:projects/my-project/ locations/global/buckets/my-bucket/views/my-view Corresponds to the JSON property name

Returns:

  • (String)


3015
3016
3017
# File 'lib/google/apis/logging_v2/classes.rb', line 3015

def name
  @name
end

#update_timeString

Output only. The last update timestamp of the view. Corresponds to the JSON property updateTime

Returns:

  • (String)


3020
3021
3022
# File 'lib/google/apis/logging_v2/classes.rb', line 3020

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3027
3028
3029
3030
3031
3032
3033
# File 'lib/google/apis/logging_v2/classes.rb', line 3027

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @filter = args[:filter] if args.key?(:filter)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end