Class: Google::Apis::LoggingV2::MonitoredResourceMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Auxiliary metadata for a MonitoredResource object. MonitoredResource objects contain the minimum set of information to uniquely identify a monitored resource instance. There is some other useful auxiliary metadata. Monitoring and Logging use an ingestion pipeline to extract metadata for cloud resources of all types, and store the metadata in this message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MonitoredResourceMetadata

Returns a new instance of MonitoredResourceMetadata.



3400
3401
3402
# File 'lib/google/apis/logging_v2/classes.rb', line 3400

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#system_labelsHash<String,Object>

Output only. Values for predefined system metadata labels. System labels are a kind of metadata extracted by Google, including "machine_image", "vpc", " subnet_id", "security_group", "name", etc. System label values can be only strings, Boolean values, or a list of strings. For example: "name": "my-test- instance", "security_group": ["a", "b", "c"], "spot_instance": false Corresponds to the JSON property systemLabels

Returns:

  • (Hash<String,Object>)


3393
3394
3395
# File 'lib/google/apis/logging_v2/classes.rb', line 3393

def system_labels
  @system_labels
end

#user_labelsHash<String,String>

Output only. A map of user-defined metadata labels. Corresponds to the JSON property userLabels

Returns:

  • (Hash<String,String>)


3398
3399
3400
# File 'lib/google/apis/logging_v2/classes.rb', line 3398

def user_labels
  @user_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3405
3406
3407
3408
# File 'lib/google/apis/logging_v2/classes.rb', line 3405

def update!(**args)
  @system_labels = args[:system_labels] if args.key?(:system_labels)
  @user_labels = args[:user_labels] if args.key?(:user_labels)
end