Class: Google::Apis::LoggingV2::OpsAnalyticsQuery
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::OpsAnalyticsQuery
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Describes a query that can be run in Log Analytics.
Instance Attribute Summary collapse
-
#query_builder ⇒ Google::Apis::LoggingV2::QueryBuilderConfig
Defines a structured query configuration that can be used instead of writing raw SQL.
-
#sql_query_text ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OpsAnalyticsQuery
constructor
A new instance of OpsAnalyticsQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OpsAnalyticsQuery
Returns a new instance of OpsAnalyticsQuery.
3493 3494 3495 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3493 def initialize(**args) update!(**args) end |
Instance Attribute Details
#query_builder ⇒ Google::Apis::LoggingV2::QueryBuilderConfig
Defines a structured query configuration that can be used instead of writing
raw SQL. This configuration represents the components of a SQL query (FROM,
SELECT, WHERE, ORDER BY, LIMIT) and is typically converted into an executable
query (e.g., BigQuery SQL) by the backend service to retrieve data for
analysis or visualization.
Corresponds to the JSON property queryBuilder
3484 3485 3486 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3484 def query_builder @query_builder end |
#sql_query_text ⇒ String
Optional. A Log Analytics SQL query in text format.If both sql_query_text and
query_builder fields are set, then the sql_query_text will be used, if its non-
empty. At least one of the two fields must be set.
Corresponds to the JSON property sqlQueryText
3491 3492 3493 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3491 def sql_query_text @sql_query_text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3498 3499 3500 3501 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3498 def update!(**args) @query_builder = args[:query_builder] if args.key?(:query_builder) @sql_query_text = args[:sql_query_text] if args.key?(:sql_query_text) end |