Class: Google::Apis::LoggingV2::SourceLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Specifies a location in a source code file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceLocation

Returns a new instance of SourceLocation.



4281
4282
4283
# File 'lib/google/apis/logging_v2/classes.rb', line 4281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fileString

Source file name. Depending on the runtime environment, this might be a simple name or a fully-qualified name. Corresponds to the JSON property file

Returns:

  • (String)


4265
4266
4267
# File 'lib/google/apis/logging_v2/classes.rb', line 4265

def file
  @file
end

#function_nameString

Human-readable name of the function or method being invoked, with optional context such as the class or package name. This information is used in contexts such as the logs viewer, where a file and line number are less meaningful. The format can vary by language. For example: qual.if.ied.Class. method (Java), dir/package.func (Go), function (Python). Corresponds to the JSON property functionName

Returns:

  • (String)


4274
4275
4276
# File 'lib/google/apis/logging_v2/classes.rb', line 4274

def function_name
  @function_name
end

#lineFixnum

Line within the source file. Corresponds to the JSON property line

Returns:

  • (Fixnum)


4279
4280
4281
# File 'lib/google/apis/logging_v2/classes.rb', line 4279

def line
  @line
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4286
4287
4288
4289
4290
# File 'lib/google/apis/logging_v2/classes.rb', line 4286

def update!(**args)
  @file = args[:file] if args.key?(:file)
  @function_name = args[:function_name] if args.key?(:function_name)
  @line = args[:line] if args.key?(:line)
end