Class: Google::Apis::LoggingV2::CreateBucketRequest
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::CreateBucketRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
The parameters to CreateBucket.
Instance Attribute Summary collapse
-
#bucket ⇒ Google::Apis::LoggingV2::LogBucket
Describes a repository in which log entries are stored.
-
#bucket_id ⇒ String
Required.
-
#parent ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateBucketRequest
constructor
A new instance of CreateBucketRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateBucketRequest
Returns a new instance of CreateBucketRequest.
653 654 655 |
# File 'lib/google/apis/logging_v2/classes.rb', line 653 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket ⇒ Google::Apis::LoggingV2::LogBucket
Describes a repository in which log entries are stored.
Corresponds to the JSON property bucket
636 637 638 |
# File 'lib/google/apis/logging_v2/classes.rb', line 636 def bucket @bucket end |
#bucket_id ⇒ String
Required. A client-assigned identifier such as "my-bucket". Identifiers are
limited to 100 characters and can include only letters, digits, underscores,
hyphens, and periods. Bucket identifiers must start with an alphanumeric
character.
Corresponds to the JSON property bucketId
644 645 646 |
# File 'lib/google/apis/logging_v2/classes.rb', line 644 def bucket_id @bucket_id end |
#parent ⇒ String
Required. The resource in which to create the log bucket: "projects/[
PROJECT_ID]/locations/[LOCATION_ID]" For example:"projects/my-project/
locations/global"
Corresponds to the JSON property parent
651 652 653 |
# File 'lib/google/apis/logging_v2/classes.rb', line 651 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
658 659 660 661 662 |
# File 'lib/google/apis/logging_v2/classes.rb', line 658 def update!(**args) @bucket = args[:bucket] if args.key?(:bucket) @bucket_id = args[:bucket_id] if args.key?(:bucket_id) @parent = args[:parent] if args.key?(:parent) end |