Class: Google::Apis::LoggingV2::CreateLinkRequest
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::CreateLinkRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
The parameters to CreateLink.
Instance Attribute Summary collapse
-
#link ⇒ Google::Apis::LoggingV2::Link
Describes a link connected to an analytics enabled bucket.
-
#link_id ⇒ String
Required.
-
#parent ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateLinkRequest
constructor
A new instance of CreateLinkRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateLinkRequest
Returns a new instance of CreateLinkRequest.
686 687 688 |
# File 'lib/google/apis/logging_v2/classes.rb', line 686 def initialize(**args) update!(**args) end |
Instance Attribute Details
#link ⇒ Google::Apis::LoggingV2::Link
Describes a link connected to an analytics enabled bucket.
Corresponds to the JSON property link
671 672 673 |
# File 'lib/google/apis/logging_v2/classes.rb', line 671 def link @link end |
#link_id ⇒ String
Required. The ID to use for the link. The link_id can have up to 100
characters. A valid link_id must only have alphanumeric characters and
underscores within it.
Corresponds to the JSON property linkId
678 679 680 |
# File 'lib/google/apis/logging_v2/classes.rb', line 678 def link_id @link_id end |
#parent ⇒ String
Required. The full resource name of the bucket to create a link for. "projects/
[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
Corresponds to the JSON property parent
684 685 686 |
# File 'lib/google/apis/logging_v2/classes.rb', line 684 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
691 692 693 694 695 |
# File 'lib/google/apis/logging_v2/classes.rb', line 691 def update!(**args) @link = args[:link] if args.key?(:link) @link_id = args[:link_id] if args.key?(:link_id) @parent = args[:parent] if args.key?(:parent) end |