Class: Google::Apis::LoggingV2::FilterExpression
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::FilterExpression
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
This is a leaf of the FilterPredicate. Ex: field: json_payload.message.
error_code, filter_value:numeric_value: 400, comparator: EQUAL_TO The
field will be schema field that is selected using the . annotation to display
the drill down value. The value will be the user inputted text that the filter
is comparing against.
Instance Attribute Summary collapse
-
#comparator ⇒ String
The comparison type to use for the filter.
-
#field_source ⇒ Google::Apis::LoggingV2::FieldSource
A source that can be used to represent a "field of data" within various parts of a structured query, such as in SELECT, WHERE, or ORDER BY clauses.
-
#field_source_value ⇒ Google::Apis::LoggingV2::FieldSource
A source that can be used to represent a "field of data" within various parts of a structured query, such as in SELECT, WHERE, or ORDER BY clauses.
-
#is_negation ⇒ Boolean
(also: #is_negation?)
Determines if the NOT flag should be added to the comparator.
-
#literal_value ⇒ Object
The Value will be used to hold user defined constants set as the Right Hand Side of the filter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FilterExpression
constructor
A new instance of FilterExpression.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FilterExpression
Returns a new instance of FilterExpression.
1019 1020 1021 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1019 def initialize(**args) update!(**args) end |
Instance Attribute Details
#comparator ⇒ String
The comparison type to use for the filter.
Corresponds to the JSON property comparator
989 990 991 |
# File 'lib/google/apis/logging_v2/classes.rb', line 989 def comparator @comparator end |
#field_source ⇒ Google::Apis::LoggingV2::FieldSource
A source that can be used to represent a "field of data" within various parts
of a structured query, such as in SELECT, WHERE, or ORDER BY clauses. The term
"field of data" is used here because it is not limited to literal fields in
the underlying data schema.
Corresponds to the JSON property fieldSource
997 998 999 |
# File 'lib/google/apis/logging_v2/classes.rb', line 997 def field_source @field_source end |
#field_source_value ⇒ Google::Apis::LoggingV2::FieldSource
A source that can be used to represent a "field of data" within various parts
of a structured query, such as in SELECT, WHERE, or ORDER BY clauses. The term
"field of data" is used here because it is not limited to literal fields in
the underlying data schema.
Corresponds to the JSON property fieldSourceValue
1005 1006 1007 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1005 def field_source_value @field_source_value end |
#is_negation ⇒ Boolean Also known as: is_negation?
Determines if the NOT flag should be added to the comparator.
Corresponds to the JSON property isNegation
1010 1011 1012 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1010 def is_negation @is_negation end |
#literal_value ⇒ Object
The Value will be used to hold user defined constants set as the Right Hand
Side of the filter.
Corresponds to the JSON property literalValue
1017 1018 1019 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1017 def literal_value @literal_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1024 1025 1026 1027 1028 1029 1030 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1024 def update!(**args) @comparator = args[:comparator] if args.key?(:comparator) @field_source = args[:field_source] if args.key?(:field_source) @field_source_value = args[:field_source_value] if args.key?(:field_source_value) @is_negation = args[:is_negation] if args.key?(:is_negation) @literal_value = args[:literal_value] if args.key?(:literal_value) end |