Class: Google::Apis::LoggingV2::FilterPredicate
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::FilterPredicate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
A filter for a query. This equates to the WHERE clause in SQL.
Instance Attribute Summary collapse
-
#child_predicates ⇒ Array<Google::Apis::LoggingV2::FilterPredicate>
The children of the filter predicate.
-
#leaf_predicate ⇒ Google::Apis::LoggingV2::FilterExpression
This is a leaf of the FilterPredicate.
-
#operator_type ⇒ String
The operator type for the filter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FilterPredicate
constructor
A new instance of FilterPredicate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FilterPredicate
Returns a new instance of FilterPredicate.
1050 1051 1052 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1050 def initialize(**args) update!(**args) end |
Instance Attribute Details
#child_predicates ⇒ Array<Google::Apis::LoggingV2::FilterPredicate>
The children of the filter predicate. This equates to the branches of the
filter predicate that could contain further nested leaves.
Corresponds to the JSON property childPredicates
1032 1033 1034 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1032 def child_predicates @child_predicates end |
#leaf_predicate ⇒ Google::Apis::LoggingV2::FilterExpression
This is a leaf of the FilterPredicate. Ex: field: json_payload.message.
error_code, filter_value:numeric_value: 400, comparator: EQUAL_TO The
field will be schema field that is selected using the . annotation to display
the drill down value. The value will be the user inputted text that the filter
is comparing against.
Corresponds to the JSON property leafPredicate
1041 1042 1043 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1041 def leaf_predicate @leaf_predicate end |
#operator_type ⇒ String
The operator type for the filter. Currently there is no support for multiple
levels of nesting, so this will be a single value with no joining of different
operator types
Corresponds to the JSON property operatorType
1048 1049 1050 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1048 def operator_type @operator_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1055 1056 1057 1058 1059 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1055 def update!(**args) @child_predicates = args[:child_predicates] if args.key?(:child_predicates) @leaf_predicate = args[:leaf_predicate] if args.key?(:leaf_predicate) @operator_type = args[:operator_type] if args.key?(:operator_type) end |