Class: Google::Apis::LoggingV2::FunctionApplication

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Defines the aggregation function to apply to this field. This message is used only when operation is set to AGGREGATE.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FunctionApplication

Returns a new instance of FunctionApplication.



1085
1086
1087
# File 'lib/google/apis/logging_v2/classes.rb', line 1085

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parametersArray<Object>

Optional. Parameters to be applied to the aggregation. Aggregations that support or require parameters are listed above. Corresponds to the JSON property parameters

Returns:

  • (Array<Object>)


1071
1072
1073
# File 'lib/google/apis/logging_v2/classes.rb', line 1071

def parameters
  @parameters
end

#typeString

Required. Specifies the aggregation function. Use one of the following string identifiers: "average": Computes the average (AVG). Applies only to numeric values. "count": Counts the number of values (COUNT). "count-distinct": Counts the number of distinct values (COUNT DISTINCT). "count-distinct-approx": Approximates the count of distinct values (APPROX_COUNT_DISTINCT). "max": Finds the maximum value (MAX). Applies only to numeric values. "min": Finds the minimum value (MIN). Applies only to numeric values. "sum": Computes the sum (SUM). Applies only to numeric values. Corresponds to the JSON property type

Returns:

  • (String)


1083
1084
1085
# File 'lib/google/apis/logging_v2/classes.rb', line 1083

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1090
1091
1092
1093
# File 'lib/google/apis/logging_v2/classes.rb', line 1090

def update!(**args)
  @parameters = args[:parameters] if args.key?(:parameters)
  @type = args[:type] if args.key?(:type)
end