Class: Google::Apis::LoggingV2::IndexConfig
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::IndexConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Configuration for an indexed field.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#field_path ⇒ String
Required.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IndexConfig
constructor
A new instance of IndexConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IndexConfig
Returns a new instance of IndexConfig.
1296 1297 1298 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1296 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the index was last modified.This is used to
return the timestamp, and will be ignored if supplied during update.
Corresponds to the JSON property createTime
1281 1282 1283 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1281 def create_time @create_time end |
#field_path ⇒ String
Required. The LogEntry field path to index.Note that some paths are
automatically indexed, and other paths are not eligible for indexing. See
indexing documentation( https://docs.cloud.google.com/logging/docs/analyze/
custom-index) for details.For example: jsonPayload.request.status
Corresponds to the JSON property fieldPath
1289 1290 1291 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1289 def field_path @field_path end |
#type ⇒ String
Required. The type of data in this index.
Corresponds to the JSON property type
1294 1295 1296 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1294 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1301 1302 1303 1304 1305 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1301 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @field_path = args[:field_path] if args.key?(:field_path) @type = args[:type] if args.key?(:type) end |