Class: Google::Apis::LoggingV2::IndexConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Configuration for an indexed field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IndexConfig

Returns a new instance of IndexConfig.



1287
1288
1289
# File 'lib/google/apis/logging_v2/classes.rb', line 1287

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the index was last modified.This is used to return the timestamp, and will be ignored if supplied during update. Corresponds to the JSON property createTime

Returns:

  • (String)


1272
1273
1274
# File 'lib/google/apis/logging_v2/classes.rb', line 1272

def create_time
  @create_time
end

#field_pathString

Required. The LogEntry field path to index.Note that some paths are automatically indexed, and other paths are not eligible for indexing. See indexing documentation( https://docs.cloud.google.com/logging/docs/analyze/ custom-index) for details.For example: jsonPayload.request.status Corresponds to the JSON property fieldPath

Returns:

  • (String)


1280
1281
1282
# File 'lib/google/apis/logging_v2/classes.rb', line 1280

def field_path
  @field_path
end

#typeString

Required. The type of data in this index. Corresponds to the JSON property type

Returns:

  • (String)


1285
1286
1287
# File 'lib/google/apis/logging_v2/classes.rb', line 1285

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1292
1293
1294
1295
1296
# File 'lib/google/apis/logging_v2/classes.rb', line 1292

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @field_path = args[:field_path] if args.key?(:field_path)
  @type = args[:type] if args.key?(:type)
end