Class: Google::Apis::LoggingV2::ListBucketsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

The response from ListBuckets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBucketsResponse

Returns a new instance of ListBucketsResponse.



1476
1477
1478
# File 'lib/google/apis/logging_v2/classes.rb', line 1476

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucketsArray<Google::Apis::LoggingV2::LogBucket>

A list of buckets. Corresponds to the JSON property buckets



1467
1468
1469
# File 'lib/google/apis/logging_v2/classes.rb', line 1467

def buckets
  @buckets
end

#next_page_tokenString

If there might be more results than appear in this response, then nextPageToken is included. To get the next set of results, call the same method again using the value of nextPageToken as pageToken. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1474
1475
1476
# File 'lib/google/apis/logging_v2/classes.rb', line 1474

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1481
1482
1483
1484
# File 'lib/google/apis/logging_v2/classes.rb', line 1481

def update!(**args)
  @buckets = args[:buckets] if args.key?(:buckets)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end