Class: Google::Apis::LoggingV2::ListLinksResponse
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::ListLinksResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
The response from ListLinks.
Instance Attribute Summary collapse
-
#links ⇒ Array<Google::Apis::LoggingV2::Link>
A list of links.
-
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then nextPageToken is included.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLinksResponse
constructor
A new instance of ListLinksResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLinksResponse
Returns a new instance of ListLinksResponse.
1530 1531 1532 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1530 def initialize(**args) update!(**args) end |
Instance Attribute Details
#links ⇒ Array<Google::Apis::LoggingV2::Link>
A list of links.
Corresponds to the JSON property links
1521 1522 1523 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1521 def links @links end |
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
nextPageToken is included. To get the next set of results, call the same
method again using the value of nextPageToken as pageToken.
Corresponds to the JSON property nextPageToken
1528 1529 1530 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1528 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1535 1536 1537 1538 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1535 def update!(**args) @links = args[:links] if args.key?(:links) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |