Class: Google::Apis::LoggingV2::ListLinksResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

The response from ListLinks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListLinksResponse

Returns a new instance of ListLinksResponse.



1327
1328
1329
# File 'lib/google/apis/logging_v2/classes.rb', line 1327

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

A list of links. Corresponds to the JSON property links

Returns:



1318
1319
1320
# File 'lib/google/apis/logging_v2/classes.rb', line 1318

def links
  @links
end

#next_page_tokenString

If there might be more results than those appearing in this response, then nextPageToken is included. To get the next set of results, call the same method again using the value of nextPageToken as pageToken. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1325
1326
1327
# File 'lib/google/apis/logging_v2/classes.rb', line 1325

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1332
1333
1334
1335
# File 'lib/google/apis/logging_v2/classes.rb', line 1332

def update!(**args)
  @links = args[:links] if args.key?(:links)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end