Class: Google::Apis::LoggingV2::ListLogEntriesRequest
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::ListLogEntriesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
The parameters to ListLogEntries.
Instance Attribute Summary collapse
-
#filter ⇒ String
Optional.
-
#order_by ⇒ String
Optional.
-
#page_size ⇒ Fixnum
Optional.
-
#page_token ⇒ String
Optional.
-
#project_ids ⇒ Array<String>
Optional.
-
#resource_names ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLogEntriesRequest
constructor
A new instance of ListLogEntriesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLogEntriesRequest
Returns a new instance of ListLogEntriesRequest.
1638 1639 1640 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1638 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Optional. A filter that chooses which log entries to return. For more
information, see Logging query language (https://$universe.dns_names.
final_documentation_domain/logging/docs/view/logging-query-language).Only log
entries that match the filter are returned. An empty filter matches all log
entries in the resources listed in resource_names. Referencing a parent
resource that is not listed in resource_names will cause the filter to return
no results. The maximum length of a filter is 20,000 characters.To make
queries faster, you can make the filter more selective by using restrictions
on indexed fields (https://$universe.dns_names.final_documentation_domain/
logging/docs/view/logging-query-language#indexed-fields) as well as limit the
time range of the query by adding range restrictions on the timestamp field.
Corresponds to the JSON property filter
1583 1584 1585 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1583 def filter @filter end |
#order_by ⇒ String
Optional. How the results should be sorted. Presently, the only permitted
values are "timestamp asc" (default) and "timestamp desc". The first option
returns entries in order of increasing values of LogEntry.timestamp (oldest
first), and the second option returns entries in order of decreasing
timestamps (newest first). Entries with equal timestamps are returned in order
of their insert_id values.We recommend setting the order_by field to "
timestamp desc" when listing recently ingested log entries. If not set, the
default value of "timestamp asc" may take a long time to fetch matching logs
that are only recently ingested.
Corresponds to the JSON property orderBy
1596 1597 1598 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1596 def order_by @order_by end |
#page_size ⇒ Fixnum
Optional. The maximum number of results to return from this request. Default
is 50. If the value is negative, the request is rejected.The presence of
next_page_token in the response indicates that more results might be available.
Corresponds to the JSON property pageSize
1603 1604 1605 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1603 def page_size @page_size end |
#page_token ⇒ String
Optional. If present, then retrieve the next batch of results from the
preceding call to this method. page_token must be the value of next_page_token
from the previous response. The values of other method parameters should be
identical to those in the previous call.
Corresponds to the JSON property pageToken
1611 1612 1613 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1611 def page_token @page_token end |
#project_ids ⇒ Array<String>
Optional. Deprecated. Use resource_names instead. One or more project
identifiers or project numbers from which to retrieve log entries. Example: "
my-project-1A".
Corresponds to the JSON property projectIds
1618 1619 1620 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1618 def project_ids @project_ids end |
#resource_names ⇒ Array<String>
Required. Names of one or more parent resources from which to retrieve log
entries. Resources may either be resource containers or specific LogViews. For
the case of resource containers, all logs ingested into that container will be
returned regardless of which LogBuckets they are actually stored in - i.e.
these queries may fan out to multiple regions. In the event of region
unavailability, specify a specific set of LogViews that do not include the
unavailable region. projects/[PROJECT_ID] organizations/[ORGANIZATION_ID]
billingAccounts/[BILLING_ACCOUNT_ID] folders/[FOLDER_ID] projects/[PROJECT_ID]/
locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID] organizations/[
ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]
billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]/buckets/[
BUCKET_ID]/views/[VIEW_ID] folders/[FOLDER_ID]/locations/[LOCATION_ID]/buckets/
[BUCKET_ID]/views/[VIEW_ID]Projects listed in the project_ids field are added
to this list. A maximum of 100 resources may be specified in a single request.
Corresponds to the JSON property resourceNames
1636 1637 1638 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1636 def resource_names @resource_names end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1643 1644 1645 1646 1647 1648 1649 1650 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1643 def update!(**args) @filter = args[:filter] if args.key?(:filter) @order_by = args[:order_by] if args.key?(:order_by) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @project_ids = args[:project_ids] if args.key?(:project_ids) @resource_names = args[:resource_names] if args.key?(:resource_names) end |