Class: Google::Apis::LoggingV2::ListLogEntriesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

The parameters to ListLogEntries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListLogEntriesRequest

Returns a new instance of ListLogEntriesRequest.



1435
1436
1437
# File 'lib/google/apis/logging_v2/classes.rb', line 1435

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Optional. A filter that chooses which log entries to return. For more information, see Logging query language (https://$universe.dns_names. final_documentation_domain/logging/docs/view/logging-query-language).Only log entries that match the filter are returned. An empty filter matches all log entries in the resources listed in resource_names. Referencing a parent resource that is not listed in resource_names will cause the filter to return no results. The maximum length of a filter is 20,000 characters.To make queries faster, you can make the filter more selective by using restrictions on indexed fields (https://$universe.dns_names.final_documentation_domain/ logging/docs/view/logging-query-language#indexed-fields) as well as limit the time range of the query by adding range restrictions on the timestamp field. Corresponds to the JSON property filter

Returns:

  • (String)


1380
1381
1382
# File 'lib/google/apis/logging_v2/classes.rb', line 1380

def filter
  @filter
end

#order_byString

Optional. How the results should be sorted. Presently, the only permitted values are "timestamp asc" (default) and "timestamp desc". The first option returns entries in order of increasing values of LogEntry.timestamp (oldest first), and the second option returns entries in order of decreasing timestamps (newest first). Entries with equal timestamps are returned in order of their insert_id values.We recommend setting the order_by field to " timestamp desc" when listing recently ingested log entries. If not set, the default value of "timestamp asc" may take a long time to fetch matching logs that are only recently ingested. Corresponds to the JSON property orderBy

Returns:

  • (String)


1393
1394
1395
# File 'lib/google/apis/logging_v2/classes.rb', line 1393

def order_by
  @order_by
end

#page_sizeFixnum

Optional. The maximum number of results to return from this request. Default is 50. If the value is negative, the request is rejected.The presence of next_page_token in the response indicates that more results might be available. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


1400
1401
1402
# File 'lib/google/apis/logging_v2/classes.rb', line 1400

def page_size
  @page_size
end

#page_tokenString

Optional. If present, then retrieve the next batch of results from the preceding call to this method. page_token must be the value of next_page_token from the previous response. The values of other method parameters should be identical to those in the previous call. Corresponds to the JSON property pageToken

Returns:

  • (String)


1408
1409
1410
# File 'lib/google/apis/logging_v2/classes.rb', line 1408

def page_token
  @page_token
end

#project_idsArray<String>

Optional. Deprecated. Use resource_names instead. One or more project identifiers or project numbers from which to retrieve log entries. Example: " my-project-1A". Corresponds to the JSON property projectIds

Returns:

  • (Array<String>)


1415
1416
1417
# File 'lib/google/apis/logging_v2/classes.rb', line 1415

def project_ids
  @project_ids
end

#resource_namesArray<String>

Required. Names of one or more parent resources from which to retrieve log entries. Resources may either be resource containers or specific LogViews. For the case of resource containers, all logs ingested into that container will be returned regardless of which LogBuckets they are actually stored in - i.e. these queries may fan out to multiple regions. In the event of region unavailability, specify a specific set of LogViews that do not include the unavailable region. projects/[PROJECT_ID] organizations/[ORGANIZATION_ID] billingAccounts/[BILLING_ACCOUNT_ID] folders/[FOLDER_ID] projects/[PROJECT_ID]/ locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID] organizations/[ ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID] billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]/buckets/[ BUCKET_ID]/views/[VIEW_ID] folders/[FOLDER_ID]/locations/[LOCATION_ID]/buckets/ [BUCKET_ID]/views/[VIEW_ID]Projects listed in the project_ids field are added to this list. A maximum of 100 resources may be specified in a single request. Corresponds to the JSON property resourceNames

Returns:

  • (Array<String>)


1433
1434
1435
# File 'lib/google/apis/logging_v2/classes.rb', line 1433

def resource_names
  @resource_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1440
1441
1442
1443
1444
1445
1446
1447
# File 'lib/google/apis/logging_v2/classes.rb', line 1440

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @order_by = args[:order_by] if args.key?(:order_by)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @project_ids = args[:project_ids] if args.key?(:project_ids)
  @resource_names = args[:resource_names] if args.key?(:resource_names)
end