Class: Google::Apis::LoggingV2::ListLogMetricsResponse
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::ListLogMetricsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Result returned from ListLogMetrics.
Instance Attribute Summary collapse
-
#metrics ⇒ Array<Google::Apis::LoggingV2::LogMetric>
A list of logs-based metrics.
-
#next_page_token ⇒ String
If there might be more results than appear in this response, then nextPageToken is included.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLogMetricsResponse
constructor
A new instance of ListLogMetricsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLogMetricsResponse
Returns a new instance of ListLogMetricsResponse.
1713 1714 1715 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1713 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metrics ⇒ Array<Google::Apis::LoggingV2::LogMetric>
A list of logs-based metrics.
Corresponds to the JSON property metrics
1704 1705 1706 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1704 def metrics @metrics end |
#next_page_token ⇒ String
If there might be more results than appear in this response, then
nextPageToken is included. To get the next set of results, call this method
again using the value of nextPageToken as pageToken.
Corresponds to the JSON property nextPageToken
1711 1712 1713 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1711 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1718 1719 1720 1721 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1718 def update!(**args) @metrics = args[:metrics] if args.key?(:metrics) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |