Class: Google::Apis::LoggingV2::ListLogMetricsResponse
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::ListLogMetricsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Result returned from ListLogMetrics.
Instance Attribute Summary collapse
-
#metrics ⇒ Array<Google::Apis::LoggingV2::LogMetric>
A list of logs-based metrics.
-
#next_page_token ⇒ String
If there might be more results than appear in this response, then nextPageToken is included.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLogMetricsResponse
constructor
A new instance of ListLogMetricsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLogMetricsResponse
Returns a new instance of ListLogMetricsResponse.
1501 1502 1503 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1501 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metrics ⇒ Array<Google::Apis::LoggingV2::LogMetric>
A list of logs-based metrics.
Corresponds to the JSON property metrics
1492 1493 1494 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1492 def metrics @metrics end |
#next_page_token ⇒ String
If there might be more results than appear in this response, then
nextPageToken is included. To get the next set of results, call this method
again using the value of nextPageToken as pageToken.
Corresponds to the JSON property nextPageToken
1499 1500 1501 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1499 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1506 1507 1508 1509 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1506 def update!(**args) @metrics = args[:metrics] if args.key?(:metrics) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |