Class: Google::Apis::LoggingV2::ListLogScopesResponse
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::ListLogScopesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
The response from ListLogScopes. Every project has a _Default log scope that cannot be modified or deleted.
Instance Attribute Summary collapse
-
#log_scopes ⇒ Array<Google::Apis::LoggingV2::LogScope>
A list of log scopes.
-
#next_page_token ⇒ String
If there might be more results than appear in this response, then nextPageToken is included.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLogScopesResponse
constructor
A new instance of ListLogScopesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLogScopesResponse
Returns a new instance of ListLogScopesResponse.
1732 1733 1734 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1732 def initialize(**args) update!(**args) end |
Instance Attribute Details
#log_scopes ⇒ Array<Google::Apis::LoggingV2::LogScope>
A list of log scopes.
Corresponds to the JSON property logScopes
1723 1724 1725 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1723 def log_scopes @log_scopes end |
#next_page_token ⇒ String
If there might be more results than appear in this response, then
nextPageToken is included. To get the next set of results, call the same
method again using the value of nextPageToken as pageToken.
Corresponds to the JSON property nextPageToken
1730 1731 1732 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1730 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1737 1738 1739 1740 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1737 def update!(**args) @log_scopes = args[:log_scopes] if args.key?(:log_scopes) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |