Class: Google::Apis::LoggingV2::ListLogsResponse
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::ListLogsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Result returned from ListLogs.
Instance Attribute Summary collapse
-
#log_names ⇒ Array<String>
A list of log names.
-
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then nextPageToken is included.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLogsResponse
constructor
A new instance of ListLogsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLogsResponse
Returns a new instance of ListLogsResponse.
1557 1558 1559 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1557 def initialize(**args) update!(**args) end |
Instance Attribute Details
#log_names ⇒ Array<String>
A list of log names. For example, "projects/my-project/logs/syslog" or "
organizations/123/logs/cloudresourcemanager.googleapis.com%2Factivity".
Corresponds to the JSON property logNames
1548 1549 1550 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1548 def log_names @log_names end |
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
nextPageToken is included. To get the next set of results, call this method
again using the value of nextPageToken as pageToken.
Corresponds to the JSON property nextPageToken
1555 1556 1557 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1555 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1562 1563 1564 1565 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1562 def update!(**args) @log_names = args[:log_names] if args.key?(:log_names) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |