Class: Google::Apis::LoggingV2::ListMonitoredResourceDescriptorsResponse
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::ListMonitoredResourceDescriptorsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Result returned from ListMonitoredResourceDescriptors.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then nextPageToken is included.
-
#resource_descriptors ⇒ Array<Google::Apis::LoggingV2::MonitoredResourceDescriptor>
A list of resource descriptors.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMonitoredResourceDescriptorsResponse
constructor
A new instance of ListMonitoredResourceDescriptorsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMonitoredResourceDescriptorsResponse
Returns a new instance of ListMonitoredResourceDescriptorsResponse.
1796 1797 1798 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1796 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
nextPageToken is included. To get the next set of results, call this method
again using the value of nextPageToken as pageToken.
Corresponds to the JSON property nextPageToken
1789 1790 1791 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1789 def next_page_token @next_page_token end |
#resource_descriptors ⇒ Array<Google::Apis::LoggingV2::MonitoredResourceDescriptor>
A list of resource descriptors.
Corresponds to the JSON property resourceDescriptors
1794 1795 1796 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1794 def resource_descriptors @resource_descriptors end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1801 1802 1803 1804 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1801 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resource_descriptors = args[:resource_descriptors] if args.key?(:resource_descriptors) end |