Class: Google::Apis::LoggingV2::ListMonitoredResourceDescriptorsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Result returned from ListMonitoredResourceDescriptors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMonitoredResourceDescriptorsResponse

Returns a new instance of ListMonitoredResourceDescriptorsResponse.



1787
1788
1789
# File 'lib/google/apis/logging_v2/classes.rb', line 1787

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

If there might be more results than those appearing in this response, then nextPageToken is included. To get the next set of results, call this method again using the value of nextPageToken as pageToken. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1780
1781
1782
# File 'lib/google/apis/logging_v2/classes.rb', line 1780

def next_page_token
  @next_page_token
end

#resource_descriptorsArray<Google::Apis::LoggingV2::MonitoredResourceDescriptor>

A list of resource descriptors. Corresponds to the JSON property resourceDescriptors



1785
1786
1787
# File 'lib/google/apis/logging_v2/classes.rb', line 1785

def resource_descriptors
  @resource_descriptors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1792
1793
1794
1795
# File 'lib/google/apis/logging_v2/classes.rb', line 1792

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @resource_descriptors = args[:resource_descriptors] if args.key?(:resource_descriptors)
end