Class: Google::Apis::LoggingV2::ListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::ListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::LoggingV2::Operation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListOperationsResponse
constructor
A new instance of ListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListOperationsResponse
Returns a new instance of ListOperationsResponse.
1616 1617 1618 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1616 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
1602 1603 1604 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1602 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::LoggingV2::Operation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
1607 1608 1609 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1607 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections. For
example, when attempting to list all resources across all supported locations.
Corresponds to the JSON property unreachable
1614 1615 1616 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1614 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1621 1622 1623 1624 1625 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1621 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |