Class: Google::Apis::LoggingV2::ListRecentQueriesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

The response from ListRecentQueries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListRecentQueriesResponse

Returns a new instance of ListRecentQueriesResponse.



1656
1657
1658
# File 'lib/google/apis/logging_v2/classes.rb', line 1656

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

If there might be more results than appear in this response, then nextPageToken is included. To get the next set of results, call the same method again using the value of nextPageToken as pageToken. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1637
1638
1639
# File 'lib/google/apis/logging_v2/classes.rb', line 1637

def next_page_token
  @next_page_token
end

#recent_queriesArray<Google::Apis::LoggingV2::RecentQuery>

A list of recent queries. Corresponds to the JSON property recentQueries



1642
1643
1644
# File 'lib/google/apis/logging_v2/classes.rb', line 1642

def recent_queries
  @recent_queries
end

#unreachableArray<String>

The unreachable resources. Each resource can be either 1) a saved query if a specific query is unreachable or 2) a location if a specific location is unreachable. "projects/[PROJECT_ID]/locations/[LOCATION_ID]/recentQueries/[ QUERY_ID]" "projects/[PROJECT_ID]/locations/[LOCATION_ID]" For example:" projects/my-project/locations/global/recentQueries/12345678" "projects/my- project/locations/global"If there are unreachable resources, the response will first return pages that contain recent queries, and then return pages that contain the unreachable resources. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1654
1655
1656
# File 'lib/google/apis/logging_v2/classes.rb', line 1654

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1661
1662
1663
1664
1665
# File 'lib/google/apis/logging_v2/classes.rb', line 1661

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @recent_queries = args[:recent_queries] if args.key?(:recent_queries)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end