Class: Google::Apis::LoggingV2::ListSavedQueriesResponse
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::ListSavedQueriesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
The response from ListSavedQueries.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If there might be more results than appear in this response, then nextPageToken is included.
-
#saved_queries ⇒ Array<Google::Apis::LoggingV2::SavedQuery>
A list of saved queries.
-
#unreachable ⇒ Array<String>
The unreachable resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSavedQueriesResponse
constructor
A new instance of ListSavedQueriesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSavedQueriesResponse
Returns a new instance of ListSavedQueriesResponse.
1899 1900 1901 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1899 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If there might be more results than appear in this response, then
nextPageToken is included. To get the next set of results, call the same
method again using the value of nextPageToken as pageToken.
Corresponds to the JSON property nextPageToken
1880 1881 1882 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1880 def next_page_token @next_page_token end |
#saved_queries ⇒ Array<Google::Apis::LoggingV2::SavedQuery>
A list of saved queries.
Corresponds to the JSON property savedQueries
1885 1886 1887 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1885 def saved_queries @saved_queries end |
#unreachable ⇒ Array<String>
The unreachable resources. It can be either 1) a saved query if a specific
query is unreachable or 2) a location if a specific location is unreachabe. "
projects/[PROJECT_ID]/locations/[LOCATION_ID]/savedQueries/[QUERY_ID]" "
projects/[PROJECT_ID]/locations/[LOCATION_ID]" For example: "projects/my-
project/locations/global/savedQueries/12345678" "projects/my-project/locations/
global" If there are unreachable resources, the response will first return
pages that contain saved queries, and then return pages that contain the
unreachable resources.
Corresponds to the JSON property unreachable
1897 1898 1899 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1897 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1904 1905 1906 1907 1908 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1904 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @saved_queries = args[:saved_queries] if args.key?(:saved_queries) @unreachable = args[:unreachable] if args.key?(:unreachable) end |