Class: Google::Apis::LoggingV2::ListSinksResponse
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::ListSinksResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Result returned from ListSinks.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If there might be more results than appear in this response, then nextPageToken is included.
-
#sinks ⇒ Array<Google::Apis::LoggingV2::LogSink>
A list of sinks.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSinksResponse
constructor
A new instance of ListSinksResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSinksResponse
Returns a new instance of ListSinksResponse.
1724 1725 1726 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1724 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If there might be more results than appear in this response, then
nextPageToken is included. To get the next set of results, call the same
method again using the value of nextPageToken as pageToken.
Corresponds to the JSON property nextPageToken
1717 1718 1719 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1717 def next_page_token @next_page_token end |
#sinks ⇒ Array<Google::Apis::LoggingV2::LogSink>
A list of sinks.
Corresponds to the JSON property sinks
1722 1723 1724 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1722 def sinks @sinks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1729 1730 1731 1732 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1729 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @sinks = args[:sinks] if args.key?(:sinks) end |