Class: Google::Apis::LoggingV2::ListViewsResponse
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::ListViewsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
The response from ListViews.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If there might be more results than appear in this response, then nextPageToken is included.
-
#views ⇒ Array<Google::Apis::LoggingV2::LogView>
A list of views.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListViewsResponse
constructor
A new instance of ListViewsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListViewsResponse
Returns a new instance of ListViewsResponse.
1963 1964 1965 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1963 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If there might be more results than appear in this response, then
nextPageToken is included. To get the next set of results, call the same
method again using the value of nextPageToken as pageToken.
Corresponds to the JSON property nextPageToken
1956 1957 1958 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1956 def next_page_token @next_page_token end |
#views ⇒ Array<Google::Apis::LoggingV2::LogView>
A list of views.
Corresponds to the JSON property views
1961 1962 1963 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1961 def views @views end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1968 1969 1970 1971 |
# File 'lib/google/apis/logging_v2/classes.rb', line 1968 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @views = args[:views] if args.key?(:views) end |