Class: Google::Apis::LoggingV2::LogBucket

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Describes a repository in which log entries are stored.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LogBucket

Returns a new instance of LogBucket.



1910
1911
1912
# File 'lib/google/apis/logging_v2/classes.rb', line 1910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analytics_enabledBoolean Also known as: analytics_enabled?

Optional. Whether log analytics is enabled for this bucket.Once enabled, log analytics features cannot be disabled. Corresponds to the JSON property analyticsEnabled

Returns:

  • (Boolean)


1838
1839
1840
# File 'lib/google/apis/logging_v2/classes.rb', line 1838

def analytics_enabled
  @analytics_enabled
end

#cmek_settingsGoogle::Apis::LoggingV2::CmekSettings

Describes the customer-managed encryption key (CMEK) settings associated with a project, folder, organization, billing account, or flexible resource.Note: CMEK for the Log Router can currently only be configured for Google Cloud organizations. Once configured, it applies to all projects and folders in the Google Cloud organization.See Enabling CMEK for Log Router (https://cloud. google.com/logging/docs/routing/managed-encryption) for more information. Corresponds to the JSON property cmekSettings



1849
1850
1851
# File 'lib/google/apis/logging_v2/classes.rb', line 1849

def cmek_settings
  @cmek_settings
end

#create_timeString

Output only. The creation timestamp of the bucket. This is not set for any of the default buckets. Corresponds to the JSON property createTime

Returns:

  • (String)


1855
1856
1857
# File 'lib/google/apis/logging_v2/classes.rb', line 1855

def create_time
  @create_time
end

#descriptionString

Optional. Describes this bucket. Corresponds to the JSON property description

Returns:

  • (String)


1860
1861
1862
# File 'lib/google/apis/logging_v2/classes.rb', line 1860

def description
  @description
end

#index_configsArray<Google::Apis::LoggingV2::IndexConfig>

Optional. A list of indexed fields and related configuration data. Corresponds to the JSON property indexConfigs



1865
1866
1867
# File 'lib/google/apis/logging_v2/classes.rb', line 1865

def index_configs
  @index_configs
end

#lifecycle_stateString

Output only. The bucket lifecycle state. Corresponds to the JSON property lifecycleState

Returns:

  • (String)


1870
1871
1872
# File 'lib/google/apis/logging_v2/classes.rb', line 1870

def lifecycle_state
  @lifecycle_state
end

#lockedBoolean Also known as: locked?

Optional. Whether the bucket is locked.The retention period on a locked bucket cannot be changed. Locked buckets may only be deleted if they are empty. Corresponds to the JSON property locked

Returns:

  • (Boolean)


1876
1877
1878
# File 'lib/google/apis/logging_v2/classes.rb', line 1876

def locked
  @locked
end

#nameString

Output only. The resource name of the bucket.For example:projects/my-project/ locations/global/buckets/my-bucketFor a list of supported locations, see Supported Regions (https://cloud.google.com/logging/docs/region-support)For the location of global it is unspecified where log entries are actually stored. After a bucket has been created, the location cannot be changed. Corresponds to the JSON property name

Returns:

  • (String)


1886
1887
1888
# File 'lib/google/apis/logging_v2/classes.rb', line 1886

def name
  @name
end

#restricted_fieldsArray<String>

Optional. Log entry field paths that are denied access in this bucket.The following fields and their children are eligible: textPayload, jsonPayload, protoPayload, httpRequest, labels, sourceLocation.Restricting a repeated field will restrict all values. Adding a parent will block all child fields. (e.g. foo.bar will block foo.bar.baz) Corresponds to the JSON property restrictedFields

Returns:

  • (Array<String>)


1895
1896
1897
# File 'lib/google/apis/logging_v2/classes.rb', line 1895

def restricted_fields
  @restricted_fields
end

#retention_daysFixnum

Optional. Logs will be retained by default for this amount of time, after which they will automatically be deleted. The minimum retention period is 1 day. If this value is set to zero at bucket creation time, the default time of 30 days will be used. Corresponds to the JSON property retentionDays

Returns:

  • (Fixnum)


1903
1904
1905
# File 'lib/google/apis/logging_v2/classes.rb', line 1903

def retention_days
  @retention_days
end

#update_timeString

Output only. The last update timestamp of the bucket. Corresponds to the JSON property updateTime

Returns:

  • (String)


1908
1909
1910
# File 'lib/google/apis/logging_v2/classes.rb', line 1908

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
# File 'lib/google/apis/logging_v2/classes.rb', line 1915

def update!(**args)
  @analytics_enabled = args[:analytics_enabled] if args.key?(:analytics_enabled)
  @cmek_settings = args[:cmek_settings] if args.key?(:cmek_settings)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @index_configs = args[:index_configs] if args.key?(:index_configs)
  @lifecycle_state = args[:lifecycle_state] if args.key?(:lifecycle_state)
  @locked = args[:locked] if args.key?(:locked)
  @name = args[:name] if args.key?(:name)
  @restricted_fields = args[:restricted_fields] if args.key?(:restricted_fields)
  @retention_days = args[:retention_days] if args.key?(:retention_days)
  @update_time = args[:update_time] if args.key?(:update_time)
end