Class: Google::Apis::LoggingV2::LogEntry
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::LogEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
An individual entry in a log.
Instance Attribute Summary collapse
-
#apphub ⇒ Google::Apis::LoggingV2::AppHub
Metadata associated with App Hub.
-
#apphub_destination ⇒ Google::Apis::LoggingV2::AppHub
Metadata associated with App Hub.
-
#apphub_source ⇒ Google::Apis::LoggingV2::AppHub
Metadata associated with App Hub.
-
#error_groups ⇒ Array<Google::Apis::LoggingV2::LogErrorGroup>
Output only.
-
#http_request ⇒ Google::Apis::LoggingV2::HttpRequest
A common proto for logging HTTP requests.
-
#insert_id ⇒ String
Optional.
-
#json_payload ⇒ Hash<String,Object>
The log entry payload, represented as a structure that is expressed as a JSON object.
-
#labels ⇒ Hash<String,String>
Optional.
-
#log_name ⇒ String
Required.
-
#metadata ⇒ Google::Apis::LoggingV2::MonitoredResourceMetadata
Auxiliary metadata for a MonitoredResource object.
-
#operation ⇒ Google::Apis::LoggingV2::LogEntryOperation
Additional information about a potentially long-running operation with which a log entry is associated.
-
#proto_payload ⇒ Hash<String,Object>
The log entry payload, represented as a protocol buffer.
-
#receive_timestamp ⇒ String
Output only.
-
#resource ⇒ Google::Apis::LoggingV2::MonitoredResource
An object representing a resource that can be used for monitoring, logging, billing, or other purposes.
-
#severity ⇒ String
Optional.
-
#source_location ⇒ Google::Apis::LoggingV2::LogEntrySourceLocation
Additional information about the source code location that produced the log entry.
-
#span_id ⇒ String
Optional.
-
#split ⇒ Google::Apis::LoggingV2::LogSplit
Additional information used to correlate multiple log entries.
-
#text_payload ⇒ String
The log entry payload, represented as a Unicode string (UTF-8).
-
#timestamp ⇒ String
Optional.
-
#trace ⇒ String
Optional.
-
#trace_sampled ⇒ Boolean
(also: #trace_sampled?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LogEntry
constructor
A new instance of LogEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LogEntry
Returns a new instance of LogEntry.
2341 2342 2343 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#apphub ⇒ Google::Apis::LoggingV2::AppHub
Metadata associated with App Hub.
Corresponds to the JSON property apphub
2140 2141 2142 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2140 def apphub @apphub end |
#apphub_destination ⇒ Google::Apis::LoggingV2::AppHub
Metadata associated with App Hub.
Corresponds to the JSON property apphubDestination
2145 2146 2147 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2145 def apphub_destination @apphub_destination end |
#apphub_source ⇒ Google::Apis::LoggingV2::AppHub
Metadata associated with App Hub.
Corresponds to the JSON property apphubSource
2150 2151 2152 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2150 def apphub_source @apphub_source end |
#error_groups ⇒ Array<Google::Apis::LoggingV2::LogErrorGroup>
Output only. The Error Reporting (https://cloud.google.com/error-reporting)
error groups associated with this LogEntry. Error Reporting sets the values
for this field during error group creation.For more information, see View
error details( https://cloud.google.com/error-reporting/docs/viewing-errors#
view_error_details)This field isn't available during log routing (https://
cloud.google.com/logging/docs/routing/overview)
Corresponds to the JSON property errorGroups
2160 2161 2162 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2160 def error_groups @error_groups end |
#http_request ⇒ Google::Apis::LoggingV2::HttpRequest
A common proto for logging HTTP requests. Only contains semantics defined by
the HTTP specification. Product-specific logging information MUST be defined
in a separate message.
Corresponds to the JSON property httpRequest
2167 2168 2169 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2167 def http_request @http_request end |
#insert_id ⇒ String
Optional. A unique identifier for the log entry. If you provide a value, then
Logging considers other log entries in the same project, with the same
timestamp, and with the same insert_id to be duplicates which are removed in a
single query result. However, there are no guarantees of de-duplication in the
export of logs.If the insert_id is omitted when writing a log entry, the
Logging API assigns its own unique identifier in this field.In queries, the
insert_id is also used to order log entries that have the same log_name and
timestamp values.
Corresponds to the JSON property insertId
2179 2180 2181 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2179 def insert_id @insert_id end |
#json_payload ⇒ Hash<String,Object>
The log entry payload, represented as a structure that is expressed as a JSON
object.
Corresponds to the JSON property jsonPayload
2185 2186 2187 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2185 def json_payload @json_payload end |
#labels ⇒ Hash<String,String>
Optional. A map of key, value pairs that provides additional information about
the log entry. The labels can be user-defined or system-defined.User-defined
labels are arbitrary key, value pairs that you can use to classify logs.System-
defined labels are defined by cloud services for platform logs. They have two
components - a service namespace component and the attribute name. For example:
compute.googleapis.com/resource_name.Cloud Logging truncates label keys that
exceed 512 B and label values that exceed 64 KB upon their associated log
entry being written. The truncation is indicated by an ellipsis at the end of
the character string.
Corresponds to the JSON property labels
2198 2199 2200 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2198 def labels @labels end |
#log_name ⇒ String
Required. The resource name of the log to which this log entry belongs: "
projects/[PROJECT_ID]/logs/[LOG_ID]" "organizations/[ORGANIZATION_ID]/logs/[
LOG_ID]" "billingAccounts/[BILLING_ACCOUNT_ID]/logs/[LOG_ID]" "folders/[
FOLDER_ID]/logs/[LOG_ID]" A project number may be used in place of PROJECT_ID.
The project number is translated to its corresponding PROJECT_ID internally
and the log_name field will contain PROJECT_ID in queries and exports.[LOG_ID]
must be URL-encoded within log_name. Example: "organizations/1234567890/logs/
cloudresourcemanager.googleapis.com%2Factivity".[LOG_ID] must be less than 512
characters long and can only include the following characters: upper and lower
case alphanumeric characters, forward-slash, underscore, hyphen, and period.
For backward compatibility, if log_name begins with a forward-slash, such as /
projects/..., then the log entry is processed as usual, but the forward-slash
is removed. Listing the log entry will not show the leading slash and
filtering for a log name with a leading slash will never return any results.
Corresponds to the JSON property logName
2216 2217 2218 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2216 def log_name @log_name end |
#metadata ⇒ Google::Apis::LoggingV2::MonitoredResourceMetadata
Auxiliary metadata for a MonitoredResource object. MonitoredResource objects
contain the minimum set of information to uniquely identify a monitored
resource instance. There is some other useful auxiliary metadata. Monitoring
and Logging use an ingestion pipeline to extract metadata for cloud resources
of all types, and store the metadata in this message.
Corresponds to the JSON property metadata
2225 2226 2227 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2225 def @metadata end |
#operation ⇒ Google::Apis::LoggingV2::LogEntryOperation
Additional information about a potentially long-running operation with which a
log entry is associated.
Corresponds to the JSON property operation
2231 2232 2233 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2231 def operation @operation end |
#proto_payload ⇒ Hash<String,Object>
The log entry payload, represented as a protocol buffer. Some Google Cloud
Platform services use this field for their log entry payloads.The following
protocol buffer types are supported; user-defined types are not supported:"
type.googleapis.com/google.cloud.audit.AuditLog" "type.googleapis.com/google.
appengine.logging.v1.RequestLog"
Corresponds to the JSON property protoPayload
2240 2241 2242 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2240 def proto_payload @proto_payload end |
#receive_timestamp ⇒ String
Output only. The time the log entry was received by Logging.
Corresponds to the JSON property receiveTimestamp
2245 2246 2247 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2245 def @receive_timestamp end |
#resource ⇒ Google::Apis::LoggingV2::MonitoredResource
An object representing a resource that can be used for monitoring, logging,
billing, or other purposes. Examples include virtual machine instances,
databases, and storage devices such as disks. The type field identifies a
MonitoredResourceDescriptor object that describes the resource's schema.
Information in the labels field identifies the actual resource and its
attributes according to the schema. For example, a particular Compute Engine
VM instance could be represented by the following object, because the
MonitoredResourceDescriptor for "gce_instance" has labels "project_id", "
instance_id" and "zone": "type": "gce_instance", "labels": "project_id": "
my-project", "instance_id": "12345678901234", "zone": "us-central1-a" `
Corresponds to the JSON propertyresource`
2259 2260 2261 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2259 def resource @resource end |
#severity ⇒ String
Optional. The severity of the log entry. The default value is LogSeverity.
DEFAULT.
Corresponds to the JSON property severity
2265 2266 2267 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2265 def severity @severity end |
#source_location ⇒ Google::Apis::LoggingV2::LogEntrySourceLocation
Additional information about the source code location that produced the log
entry.
Corresponds to the JSON property sourceLocation
2271 2272 2273 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2271 def source_location @source_location end |
#span_id ⇒ String
Optional. The ID of the Cloud Trace (https://docs.cloud.google.com/trace/docs)
span associated with the current operation in which the log is being written.A
Span (https://docs.cloud.google.com/trace/docs/reference/v2/rest/v2/projects.
traces/batchWrite#Span) represents a single operation within a trace. Whereas
a trace may involve multiple different microservices running on multiple
different machines, a span generally corresponds to a single logical operation
being performed in a single instance of a microservice on one specific machine.
Spans are the nodes within the tree that is a trace.Applications that are
instrumented for tracing (https://docs.cloud.google.com/trace/docs/setup) will
generally assign a new, unique span ID on each incoming request. It is also
common to create and record additional spans corresponding to internal
processing elements as well as issuing requests to dependencies.The span ID is
expected to be a 16-character, hexadecimal encoding of an 8-byte array and
should not be zero. It should be unique within the trace and should, ideally,
be generated in a manner that is uniformly random.Example values:
000000000000004a 7a2190356c3fc94b 0000f00300090021 d39223e101960076
Corresponds to the JSON property spanId
2291 2292 2293 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2291 def span_id @span_id end |
#split ⇒ Google::Apis::LoggingV2::LogSplit
Additional information used to correlate multiple log entries. Used when a
single LogEntry would exceed the Google Cloud Logging size limit and is split
across multiple log entries.
Corresponds to the JSON property split
2298 2299 2300 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2298 def split @split end |
#text_payload ⇒ String
The log entry payload, represented as a Unicode string (UTF-8).
Corresponds to the JSON property textPayload
2303 2304 2305 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2303 def text_payload @text_payload end |
#timestamp ⇒ String
Optional. The time the event described by the log entry occurred. This time is
used to compute the log entry's age and to enforce the logs retention period.
If this field is omitted in a new log entry, then Logging assigns it the
current time. Timestamps have nanosecond accuracy, but trailing zeros in the
fractional seconds might be omitted when the timestamp is displayed.Incoming
log entries must have timestamps that don't exceed the logs retention period (
https://cloud.google.com/logging/quotas#logs_retention_periods) in the past,
and that don't exceed 24 hours in the future. Log entries outside those time
boundaries are rejected by Logging.
Corresponds to the JSON property timestamp
2316 2317 2318 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2316 def @timestamp end |
#trace ⇒ String
Optional. The trace ID being written to Cloud Trace (https://docs.cloud.google.
com/trace/docs) in association with this log entry. For example, if your trace
data is stored in the Cloud project "my-trace-project" and if the service that
is creating the log entry receives a trace header that includes the trace ID "
12345", then the service should use "12345".The REST resource name of the
trace is also supported, but using this format is not recommended. An example
trace REST resource name is similar to "projects/my-trace-project/traces/12345"
.The trace field provides the link between logs and traces. By using this
field, you can navigate from a log entry to a trace.
Corresponds to the JSON property trace
2329 2330 2331 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2329 def trace @trace end |
#trace_sampled ⇒ Boolean Also known as: trace_sampled?
Optional. The sampling decision of the span associated with the log entry at
the time the log entry was created. This field corresponds to the sampled flag
in the W3C trace-context specification (https://www.w3.org/TR/trace-context/#
sampled-flag). A non-sampled trace value is still useful as a request
correlation identifier. The default is False.
Corresponds to the JSON property traceSampled
2338 2339 2340 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2338 def trace_sampled @trace_sampled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2346 def update!(**args) @apphub = args[:apphub] if args.key?(:apphub) @apphub_destination = args[:apphub_destination] if args.key?(:apphub_destination) @apphub_source = args[:apphub_source] if args.key?(:apphub_source) @error_groups = args[:error_groups] if args.key?(:error_groups) @http_request = args[:http_request] if args.key?(:http_request) @insert_id = args[:insert_id] if args.key?(:insert_id) @json_payload = args[:json_payload] if args.key?(:json_payload) @labels = args[:labels] if args.key?(:labels) @log_name = args[:log_name] if args.key?(:log_name) @metadata = args[:metadata] if args.key?(:metadata) @operation = args[:operation] if args.key?(:operation) @proto_payload = args[:proto_payload] if args.key?(:proto_payload) @receive_timestamp = args[:receive_timestamp] if args.key?(:receive_timestamp) @resource = args[:resource] if args.key?(:resource) @severity = args[:severity] if args.key?(:severity) @source_location = args[:source_location] if args.key?(:source_location) @span_id = args[:span_id] if args.key?(:span_id) @split = args[:split] if args.key?(:split) @text_payload = args[:text_payload] if args.key?(:text_payload) @timestamp = args[:timestamp] if args.key?(:timestamp) @trace = args[:trace] if args.key?(:trace) @trace_sampled = args[:trace_sampled] if args.key?(:trace_sampled) end |