Class: Google::Apis::LoggingV2::LogEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

An individual entry in a log.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LogEntry

Returns a new instance of LogEntry.



2138
2139
2140
# File 'lib/google/apis/logging_v2/classes.rb', line 2138

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apphubGoogle::Apis::LoggingV2::AppHub

Metadata associated with App Hub. Corresponds to the JSON property apphub



1937
1938
1939
# File 'lib/google/apis/logging_v2/classes.rb', line 1937

def apphub
  @apphub
end

#apphub_destinationGoogle::Apis::LoggingV2::AppHub

Metadata associated with App Hub. Corresponds to the JSON property apphubDestination



1942
1943
1944
# File 'lib/google/apis/logging_v2/classes.rb', line 1942

def apphub_destination
  @apphub_destination
end

#apphub_sourceGoogle::Apis::LoggingV2::AppHub

Metadata associated with App Hub. Corresponds to the JSON property apphubSource



1947
1948
1949
# File 'lib/google/apis/logging_v2/classes.rb', line 1947

def apphub_source
  @apphub_source
end

#error_groupsArray<Google::Apis::LoggingV2::LogErrorGroup>

Output only. The Error Reporting (https://cloud.google.com/error-reporting) error groups associated with this LogEntry. Error Reporting sets the values for this field during error group creation.For more information, see View error details( https://cloud.google.com/error-reporting/docs/viewing-errors# view_error_details)This field isn't available during log routing (https:// cloud.google.com/logging/docs/routing/overview) Corresponds to the JSON property errorGroups



1957
1958
1959
# File 'lib/google/apis/logging_v2/classes.rb', line 1957

def error_groups
  @error_groups
end

#http_requestGoogle::Apis::LoggingV2::HttpRequest

A common proto for logging HTTP requests. Only contains semantics defined by the HTTP specification. Product-specific logging information MUST be defined in a separate message. Corresponds to the JSON property httpRequest



1964
1965
1966
# File 'lib/google/apis/logging_v2/classes.rb', line 1964

def http_request
  @http_request
end

#insert_idString

Optional. A unique identifier for the log entry. If you provide a value, then Logging considers other log entries in the same project, with the same timestamp, and with the same insert_id to be duplicates which are removed in a single query result. However, there are no guarantees of de-duplication in the export of logs.If the insert_id is omitted when writing a log entry, the Logging API assigns its own unique identifier in this field.In queries, the insert_id is also used to order log entries that have the same log_name and timestamp values. Corresponds to the JSON property insertId

Returns:

  • (String)


1976
1977
1978
# File 'lib/google/apis/logging_v2/classes.rb', line 1976

def insert_id
  @insert_id
end

#json_payloadHash<String,Object>

The log entry payload, represented as a structure that is expressed as a JSON object. Corresponds to the JSON property jsonPayload

Returns:

  • (Hash<String,Object>)


1982
1983
1984
# File 'lib/google/apis/logging_v2/classes.rb', line 1982

def json_payload
  @json_payload
end

#labelsHash<String,String>

Optional. A map of key, value pairs that provides additional information about the log entry. The labels can be user-defined or system-defined.User-defined labels are arbitrary key, value pairs that you can use to classify logs.System- defined labels are defined by GCP services for platform logs. They have two components - a service namespace component and the attribute name. For example: compute.googleapis.com/resource_name.Cloud Logging truncates label keys that exceed 512 B and label values that exceed 64 KB upon their associated log entry being written. The truncation is indicated by an ellipsis at the end of the character string. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1995
1996
1997
# File 'lib/google/apis/logging_v2/classes.rb', line 1995

def labels
  @labels
end

#log_nameString

Required. The resource name of the log to which this log entry belongs: " projects/[PROJECT_ID]/logs/[LOG_ID]" "organizations/[ORGANIZATION_ID]/logs/[ LOG_ID]" "billingAccounts/[BILLING_ACCOUNT_ID]/logs/[LOG_ID]" "folders/[ FOLDER_ID]/logs/[LOG_ID]" A project number may be used in place of PROJECT_ID. The project number is translated to its corresponding PROJECT_ID internally and the log_name field will contain PROJECT_ID in queries and exports.[LOG_ID] must be URL-encoded within log_name. Example: "organizations/1234567890/logs/ cloudresourcemanager.googleapis.com%2Factivity".[LOG_ID] must be less than 512 characters long and can only include the following characters: upper and lower case alphanumeric characters, forward-slash, underscore, hyphen, and period. For backward compatibility, if log_name begins with a forward-slash, such as / projects/..., then the log entry is processed as usual, but the forward-slash is removed. Listing the log entry will not show the leading slash and filtering for a log name with a leading slash will never return any results. Corresponds to the JSON property logName

Returns:

  • (String)


2013
2014
2015
# File 'lib/google/apis/logging_v2/classes.rb', line 2013

def log_name
  @log_name
end

#metadataGoogle::Apis::LoggingV2::MonitoredResourceMetadata

Auxiliary metadata for a MonitoredResource object. MonitoredResource objects contain the minimum set of information to uniquely identify a monitored resource instance. There is some other useful auxiliary metadata. Monitoring and Logging use an ingestion pipeline to extract metadata for cloud resources of all types, and store the metadata in this message. Corresponds to the JSON property metadata



2022
2023
2024
# File 'lib/google/apis/logging_v2/classes.rb', line 2022

def 
  @metadata
end

#operationGoogle::Apis::LoggingV2::LogEntryOperation

Additional information about a potentially long-running operation with which a log entry is associated. Corresponds to the JSON property operation



2028
2029
2030
# File 'lib/google/apis/logging_v2/classes.rb', line 2028

def operation
  @operation
end

#proto_payloadHash<String,Object>

The log entry payload, represented as a protocol buffer. Some Google Cloud Platform services use this field for their log entry payloads.The following protocol buffer types are supported; user-defined types are not supported:" type.googleapis.com/google.cloud.audit.AuditLog" "type.googleapis.com/google. appengine.logging.v1.RequestLog" Corresponds to the JSON property protoPayload

Returns:

  • (Hash<String,Object>)


2037
2038
2039
# File 'lib/google/apis/logging_v2/classes.rb', line 2037

def proto_payload
  @proto_payload
end

#receive_timestampString

Output only. The time the log entry was received by Logging. Corresponds to the JSON property receiveTimestamp

Returns:

  • (String)


2042
2043
2044
# File 'lib/google/apis/logging_v2/classes.rb', line 2042

def receive_timestamp
  @receive_timestamp
end

#resourceGoogle::Apis::LoggingV2::MonitoredResource

An object representing a resource that can be used for monitoring, logging, billing, or other purposes. Examples include virtual machine instances, databases, and storage devices such as disks. The type field identifies a MonitoredResourceDescriptor object that describes the resource's schema. Information in the labels field identifies the actual resource and its attributes according to the schema. For example, a particular Compute Engine VM instance could be represented by the following object, because the MonitoredResourceDescriptor for "gce_instance" has labels "project_id", " instance_id" and "zone": "type": "gce_instance", "labels": "project_id": " my-project", "instance_id": "12345678901234", "zone": "us-central1-a" ` Corresponds to the JSON propertyresource`



2056
2057
2058
# File 'lib/google/apis/logging_v2/classes.rb', line 2056

def resource
  @resource
end

#severityString

Optional. The severity of the log entry. The default value is LogSeverity. DEFAULT. Corresponds to the JSON property severity

Returns:

  • (String)


2062
2063
2064
# File 'lib/google/apis/logging_v2/classes.rb', line 2062

def severity
  @severity
end

#source_locationGoogle::Apis::LoggingV2::LogEntrySourceLocation

Additional information about the source code location that produced the log entry. Corresponds to the JSON property sourceLocation



2068
2069
2070
# File 'lib/google/apis/logging_v2/classes.rb', line 2068

def source_location
  @source_location
end

#span_idString

Optional. The ID of the Cloud Trace (https://cloud.google.com/trace) span associated with the current operation in which the log is being written. For example, if a span has the REST resource name of "projects/some-project/traces/ some-trace/spans/some-span-id", then the span_id field is "some-span-id".A Span (https://cloud.google.com/trace/docs/reference/v2/rest/v2/projects.traces/ batchWrite#Span) represents a single operation within a trace. Whereas a trace may involve multiple different microservices running on multiple different machines, a span generally corresponds to a single logical operation being performed in a single instance of a microservice on one specific machine. Spans are the nodes within the tree that is a trace.Applications that are instrumented for tracing (https://cloud.google.com/trace/docs/setup) will generally assign a new, unique span ID on each incoming request. It is also common to create and record additional spans corresponding to internal processing elements as well as issuing requests to dependencies.The span ID is expected to be a 16-character, hexadecimal encoding of an 8-byte array and should not be zero. It should be unique within the trace and should, ideally, be generated in a manner that is uniformly random.Example values: 000000000000004a 7a2190356c3fc94b 0000f00300090021 d39223e101960076 Corresponds to the JSON property spanId

Returns:

  • (String)


2090
2091
2092
# File 'lib/google/apis/logging_v2/classes.rb', line 2090

def span_id
  @span_id
end

#splitGoogle::Apis::LoggingV2::LogSplit

Additional information used to correlate multiple log entries. Used when a single LogEntry would exceed the Google Cloud Logging size limit and is split across multiple log entries. Corresponds to the JSON property split



2097
2098
2099
# File 'lib/google/apis/logging_v2/classes.rb', line 2097

def split
  @split
end

#text_payloadString

The log entry payload, represented as a Unicode string (UTF-8). Corresponds to the JSON property textPayload

Returns:

  • (String)


2102
2103
2104
# File 'lib/google/apis/logging_v2/classes.rb', line 2102

def text_payload
  @text_payload
end

#timestampString

Optional. The time the event described by the log entry occurred. This time is used to compute the log entry's age and to enforce the logs retention period. If this field is omitted in a new log entry, then Logging assigns it the current time. Timestamps have nanosecond accuracy, but trailing zeros in the fractional seconds might be omitted when the timestamp is displayed.Incoming log entries must have timestamps that don't exceed the logs retention period ( https://cloud.google.com/logging/quotas#logs_retention_periods) in the past, and that don't exceed 24 hours in the future. Log entries outside those time boundaries are rejected by Logging. Corresponds to the JSON property timestamp

Returns:

  • (String)


2115
2116
2117
# File 'lib/google/apis/logging_v2/classes.rb', line 2115

def timestamp
  @timestamp
end

#traceString

Optional. The REST resource name of the trace being written to Cloud Trace ( https://cloud.google.com/trace) in association with this log entry. For example, if your trace data is stored in the Cloud project "my-trace-project" and if the service that is creating the log entry receives a trace header that includes the trace ID "12345", then the service should use "projects/my-trace- project/traces/12345".The trace field provides the link between logs and traces. By using this field, you can navigate from a log entry to a trace. Corresponds to the JSON property trace

Returns:

  • (String)


2126
2127
2128
# File 'lib/google/apis/logging_v2/classes.rb', line 2126

def trace
  @trace
end

#trace_sampledBoolean Also known as: trace_sampled?

Optional. The sampling decision of the span associated with the log entry at the time the log entry was created. This field corresponds to the sampled flag in the W3C trace-context specification (https://www.w3.org/TR/trace-context/# sampled-flag). A non-sampled trace value is still useful as a request correlation identifier. The default is False. Corresponds to the JSON property traceSampled

Returns:

  • (Boolean)


2135
2136
2137
# File 'lib/google/apis/logging_v2/classes.rb', line 2135

def trace_sampled
  @trace_sampled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
# File 'lib/google/apis/logging_v2/classes.rb', line 2143

def update!(**args)
  @apphub = args[:apphub] if args.key?(:apphub)
  @apphub_destination = args[:apphub_destination] if args.key?(:apphub_destination)
  @apphub_source = args[:apphub_source] if args.key?(:apphub_source)
  @error_groups = args[:error_groups] if args.key?(:error_groups)
  @http_request = args[:http_request] if args.key?(:http_request)
  @insert_id = args[:insert_id] if args.key?(:insert_id)
  @json_payload = args[:json_payload] if args.key?(:json_payload)
  @labels = args[:labels] if args.key?(:labels)
  @log_name = args[:log_name] if args.key?(:log_name)
  @metadata = args[:metadata] if args.key?(:metadata)
  @operation = args[:operation] if args.key?(:operation)
  @proto_payload = args[:proto_payload] if args.key?(:proto_payload)
  @receive_timestamp = args[:receive_timestamp] if args.key?(:receive_timestamp)
  @resource = args[:resource] if args.key?(:resource)
  @severity = args[:severity] if args.key?(:severity)
  @source_location = args[:source_location] if args.key?(:source_location)
  @span_id = args[:span_id] if args.key?(:span_id)
  @split = args[:split] if args.key?(:split)
  @text_payload = args[:text_payload] if args.key?(:text_payload)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
  @trace = args[:trace] if args.key?(:trace)
  @trace_sampled = args[:trace_sampled] if args.key?(:trace_sampled)
end