Class: Google::Apis::LoggingV2::LogEntryOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Additional information about a potentially long-running operation with which a log entry is associated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LogEntryOperation

Returns a new instance of LogEntryOperation.



2199
2200
2201
# File 'lib/google/apis/logging_v2/classes.rb', line 2199

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#firstBoolean Also known as: first?

Optional. Set this to True if this is the first log entry in the operation. Corresponds to the JSON property first

Returns:

  • (Boolean)


2177
2178
2179
# File 'lib/google/apis/logging_v2/classes.rb', line 2177

def first
  @first
end

#idString

Optional. An arbitrary operation identifier. Log entries with the same identifier are assumed to be part of the same operation. Corresponds to the JSON property id

Returns:

  • (String)


2184
2185
2186
# File 'lib/google/apis/logging_v2/classes.rb', line 2184

def id
  @id
end

#lastBoolean Also known as: last?

Optional. Set this to True if this is the last log entry in the operation. Corresponds to the JSON property last

Returns:

  • (Boolean)


2189
2190
2191
# File 'lib/google/apis/logging_v2/classes.rb', line 2189

def last
  @last
end

#producerString

Optional. An arbitrary producer identifier. The combination of id and producer must be globally unique. Examples for producer: "MyDivision.MyBigCompany.com", "github.com/MyProject/MyApplication". Corresponds to the JSON property producer

Returns:

  • (String)


2197
2198
2199
# File 'lib/google/apis/logging_v2/classes.rb', line 2197

def producer
  @producer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2204
2205
2206
2207
2208
2209
# File 'lib/google/apis/logging_v2/classes.rb', line 2204

def update!(**args)
  @first = args[:first] if args.key?(:first)
  @id = args[:id] if args.key?(:id)
  @last = args[:last] if args.key?(:last)
  @producer = args[:producer] if args.key?(:producer)
end