Class: Google::Apis::LoggingV2::LogEntrySourceLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Additional information about the source code location that produced the log entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LogEntrySourceLocation

Returns a new instance of LogEntrySourceLocation.



2450
2451
2452
# File 'lib/google/apis/logging_v2/classes.rb', line 2450

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fileString

Optional. Source file name. Depending on the runtime environment, this might be a simple name or a fully-qualified name. Corresponds to the JSON property file

Returns:

  • (String)


2433
2434
2435
# File 'lib/google/apis/logging_v2/classes.rb', line 2433

def file
  @file
end

#functionString

Optional. Human-readable name of the function or method being invoked, with optional context such as the class or package name. This information may be used in contexts such as the logs viewer, where a file and line number are less meaningful. The format can vary by language. For example: qual.if.ied. Class.method (Java), dir/package.func (Go), function (Python). Corresponds to the JSON property function

Returns:

  • (String)


2442
2443
2444
# File 'lib/google/apis/logging_v2/classes.rb', line 2442

def function
  @function
end

#lineFixnum

Optional. Line within the source file. 1-based; 0 indicates no line number available. Corresponds to the JSON property line

Returns:

  • (Fixnum)


2448
2449
2450
# File 'lib/google/apis/logging_v2/classes.rb', line 2448

def line
  @line
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2455
2456
2457
2458
2459
# File 'lib/google/apis/logging_v2/classes.rb', line 2455

def update!(**args)
  @file = args[:file] if args.key?(:file)
  @function = args[:function] if args.key?(:function)
  @line = args[:line] if args.key?(:line)
end