Class: Google::Apis::LoggingV2::LogExclusion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Specifies a set of log entries that are filtered out by a sink. If your Google Cloud resource receives a large volume of log entries, you can use exclusions to reduce your chargeable logs. Note that exclusions on organization-level and folder-level sinks don't apply to child resources. Note also that you cannot modify the _Required sink or exclude logs from it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LogExclusion

Returns a new instance of LogExclusion.



2325
2326
2327
# File 'lib/google/apis/logging_v2/classes.rb', line 2325

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The creation timestamp of the exclusion.This field may not be present for older exclusions. Corresponds to the JSON property createTime

Returns:

  • (String)


2286
2287
2288
# File 'lib/google/apis/logging_v2/classes.rb', line 2286

def create_time
  @create_time
end

#descriptionString

Optional. A description of this exclusion. Corresponds to the JSON property description

Returns:

  • (String)


2291
2292
2293
# File 'lib/google/apis/logging_v2/classes.rb', line 2291

def description
  @description
end

#disabledBoolean Also known as: disabled?

Optional. If set to True, then this exclusion is disabled and it does not exclude any log entries. You can update an exclusion to change the value of this field. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


2298
2299
2300
# File 'lib/google/apis/logging_v2/classes.rb', line 2298

def disabled
  @disabled
end

#filterString

Required. An advanced logs filter (https://cloud.google.com/logging/docs/view/ advanced-queries) that matches the log entries to be excluded. By using the sample function (https://cloud.google.com/logging/docs/view/advanced-queries# sample), you can exclude less than 100% of the matching log entries.For example, the following query matches 99% of low-severity log entries from Google Cloud Storage buckets:resource.type=gcs_bucket severity<ERROR sample( insertId, 0.99) Corresponds to the JSON property filter

Returns:

  • (String)


2310
2311
2312
# File 'lib/google/apis/logging_v2/classes.rb', line 2310

def filter
  @filter
end

#nameString

Optional. A client-assigned identifier, such as "load-balancer-exclusion". Identifiers are limited to 100 characters and can include only letters, digits, underscores, hyphens, and periods. First character has to be alphanumeric. Corresponds to the JSON property name

Returns:

  • (String)


2317
2318
2319
# File 'lib/google/apis/logging_v2/classes.rb', line 2317

def name
  @name
end

#update_timeString

Output only. The last update timestamp of the exclusion.This field may not be present for older exclusions. Corresponds to the JSON property updateTime

Returns:

  • (String)


2323
2324
2325
# File 'lib/google/apis/logging_v2/classes.rb', line 2323

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2330
2331
2332
2333
2334
2335
2336
2337
# File 'lib/google/apis/logging_v2/classes.rb', line 2330

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @disabled = args[:disabled] if args.key?(:disabled)
  @filter = args[:filter] if args.key?(:filter)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end