Class: Google::Apis::LoggingV2::LogExclusion
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::LogExclusion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Specifies a set of log entries that are filtered out by a sink. If your Google Cloud resource receives a large volume of log entries, you can use exclusions to reduce your chargeable logs. Note that exclusions on organization-level and folder-level sinks don't apply to child resources. Note also that you cannot modify the _Required sink or exclude logs from it.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#disabled ⇒ Boolean
(also: #disabled?)
Optional.
-
#filter ⇒ String
Required.
-
#name ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LogExclusion
constructor
A new instance of LogExclusion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LogExclusion
Returns a new instance of LogExclusion.
2325 2326 2327 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2325 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The creation timestamp of the exclusion.This field may not be
present for older exclusions.
Corresponds to the JSON property createTime
2286 2287 2288 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2286 def create_time @create_time end |
#description ⇒ String
Optional. A description of this exclusion.
Corresponds to the JSON property description
2291 2292 2293 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2291 def description @description end |
#disabled ⇒ Boolean Also known as: disabled?
Optional. If set to True, then this exclusion is disabled and it does not
exclude any log entries. You can update an exclusion to change the value of
this field.
Corresponds to the JSON property disabled
2298 2299 2300 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2298 def disabled @disabled end |
#filter ⇒ String
Required. An advanced logs filter (https://cloud.google.com/logging/docs/view/
advanced-queries) that matches the log entries to be excluded. By using the
sample function (https://cloud.google.com/logging/docs/view/advanced-queries#
sample), you can exclude less than 100% of the matching log entries.For
example, the following query matches 99% of low-severity log entries from
Google Cloud Storage buckets:resource.type=gcs_bucket severity<ERROR sample(
insertId, 0.99)
Corresponds to the JSON property filter
2310 2311 2312 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2310 def filter @filter end |
#name ⇒ String
Optional. A client-assigned identifier, such as "load-balancer-exclusion".
Identifiers are limited to 100 characters and can include only letters, digits,
underscores, hyphens, and periods. First character has to be alphanumeric.
Corresponds to the JSON property name
2317 2318 2319 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2317 def name @name end |
#update_time ⇒ String
Output only. The last update timestamp of the exclusion.This field may not be
present for older exclusions.
Corresponds to the JSON property updateTime
2323 2324 2325 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2323 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2330 2331 2332 2333 2334 2335 2336 2337 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2330 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @disabled = args[:disabled] if args.key?(:disabled) @filter = args[:filter] if args.key?(:filter) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |