Class: Google::Apis::LoggingV2::LogSink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Describes a sink used to export log entries to one of the following destinations: a Cloud Logging log bucket, a Cloud Storage bucket, a BigQuery dataset, a Pub/Sub topic, a Cloud project.A logs filter controls which log entries are exported. The sink must be created within a project, organization, billing account, or folder.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LogSink

Returns a new instance of LogSink.



2921
2922
2923
# File 'lib/google/apis/logging_v2/classes.rb', line 2921

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_optionsGoogle::Apis::LoggingV2::BigQueryOptions

Options that change functionality of a sink exporting data to BigQuery. Corresponds to the JSON property bigqueryOptions



2798
2799
2800
# File 'lib/google/apis/logging_v2/classes.rb', line 2798

def bigquery_options
  @bigquery_options
end

#create_timeString

Output only. The creation timestamp of the sink.This field may not be present for older sinks. Corresponds to the JSON property createTime

Returns:

  • (String)


2804
2805
2806
# File 'lib/google/apis/logging_v2/classes.rb', line 2804

def create_time
  @create_time
end

#descriptionString

Optional. A description of this sink.The maximum length of the description is 8000 characters. Corresponds to the JSON property description

Returns:

  • (String)


2810
2811
2812
# File 'lib/google/apis/logging_v2/classes.rb', line 2810

def description
  @description
end

#destinationString

Required. The export destination: "storage.googleapis.com/[GCS_BUCKET]" " bigquery.googleapis.com/projects/[PROJECT_ID]/datasets/[DATASET]" "pubsub. googleapis.com/projects/[PROJECT_ID]/topics/[TOPIC_ID]" "logging.googleapis. com/projects/[PROJECT_ID]" "logging.googleapis.com/projects/[PROJECT_ID]/ locations/[LOCATION_ID]/buckets/[BUCKET_ID]" The sink's writer_identity, set when the sink is created, must have permission to write to the destination or else the log entries are not exported. For more information, see Route logs to supported destinations (https://docs.cloud.google.com/logging/docs/export/ configure_export_v2). Corresponds to the JSON property destination

Returns:

  • (String)


2823
2824
2825
# File 'lib/google/apis/logging_v2/classes.rb', line 2823

def destination
  @destination
end

#disabledBoolean Also known as: disabled?

Optional. If set to true, then this sink is disabled and it does not export any log entries. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


2829
2830
2831
# File 'lib/google/apis/logging_v2/classes.rb', line 2829

def disabled
  @disabled
end

#exclusionsArray<Google::Apis::LoggingV2::LogExclusion>

Optional. Log entries that match any of these exclusion filters will not be exported.If a log entry is matched by both filter and one of exclusions it will not be exported. Corresponds to the JSON property exclusions



2837
2838
2839
# File 'lib/google/apis/logging_v2/classes.rb', line 2837

def exclusions
  @exclusions
end

#filterString

Optional. An advanced logs filter (https://docs.cloud.google.com/logging/docs/ view/building-queries#queries-by-expression). The only exported log entries are those that are in the resource owning the sink and that match the filter. For example:logName="projects/[PROJECT_ID]/logs/[LOG_ID]" AND severity>=ERROR Corresponds to the JSON property filter

Returns:

  • (String)


2845
2846
2847
# File 'lib/google/apis/logging_v2/classes.rb', line 2845

def filter
  @filter
end

#include_childrenBoolean Also known as: include_children?

Optional. This field applies only to sinks owned by organizations and folders. If the field is false, the default, only the logs owned by the sink's parent resource are available for export. If the field is true, then log entries from all the projects, folders, and billing accounts contained in the sink's parent resource are also available for export. Whether a particular log entry from the children is exported depends on the sink's filter expression.For example, if this field is true, then the filter resource.type=gce_instance would export all Compute Engine VM instance log entries from all projects in the sink's parent.To only export entries from certain child projects, filter on the project part of the log name:logName:("projects/test-project1/" OR "projects/ test-project2/") AND resource.type=gce_instance Corresponds to the JSON property includeChildren

Returns:

  • (Boolean)


2860
2861
2862
# File 'lib/google/apis/logging_v2/classes.rb', line 2860

def include_children
  @include_children
end

#intercept_childrenBoolean Also known as: intercept_children?

Optional. This field applies only to sinks owned by organizations and folders. When the value of 'intercept_children' is true, the following restrictions apply: The sink must have the include_children flag set to true. The sink destination must be a Cloud project.Also, the following behaviors apply: Any logs matched by the sink won't be included by non-_Required sinks owned by child resources. The sink appears in the results of a ListSinks call from a child resource if the value of the filter field in its request is either ' in_scope("ALL")' or 'in_scope("ANCESTOR")'. Corresponds to the JSON property interceptChildren

Returns:

  • (Boolean)


2873
2874
2875
# File 'lib/google/apis/logging_v2/classes.rb', line 2873

def intercept_children
  @intercept_children
end

#nameString

Optional. The client-assigned sink identifier, unique within the project.For example: "my-syslog-errors-to-pubsub".Sink identifiers are limited to 100 characters and can include only the following characters: upper and lower-case alphanumeric characters, underscores, hyphens, periods.First character has to be alphanumeric. Corresponds to the JSON property name

Returns:

  • (String)


2883
2884
2885
# File 'lib/google/apis/logging_v2/classes.rb', line 2883

def name
  @name
end

#output_version_formatString

Deprecated. This field is unused. Corresponds to the JSON property outputVersionFormat

Returns:

  • (String)


2888
2889
2890
# File 'lib/google/apis/logging_v2/classes.rb', line 2888

def output_version_format
  @output_version_format
end

#resource_nameString

Output only. The resource name of the sink. "projects/[PROJECT_ID]/sinks/[ SINK_NAME] "organizations/[ORGANIZATION_ID]/sinks/[SINK_NAME] "billingAccounts/ [BILLING_ACCOUNT_ID]/sinks/[SINK_NAME] "folders/[FOLDER_ID]/sinks/[SINK_NAME] For example: projects/my_project/sinks/SINK_NAME Corresponds to the JSON property resourceName

Returns:

  • (String)


2896
2897
2898
# File 'lib/google/apis/logging_v2/classes.rb', line 2896

def resource_name
  @resource_name
end

#update_timeString

Output only. The last update timestamp of the sink.This field may not be present for older sinks. Corresponds to the JSON property updateTime

Returns:

  • (String)


2902
2903
2904
# File 'lib/google/apis/logging_v2/classes.rb', line 2902

def update_time
  @update_time
end

#writer_identityString

Output only. An IAM identity—a service account or group—under which Cloud Logging writes the exported log entries to the sink's destination. This field is either set by specifying custom_writer_identity or set automatically by sinks.create and sinks.update based on the value of unique_writer_identity in those methods.Until you grant this identity write-access to the destination, log entry exports from this sink will fail. For more information, see Manage access to projects, folders, and organizations (https://docs.cloud.google.com/ iam/docs/granting-roles-to-service-accounts# granting_access_to_a_service_account_for_a_resource). Consult the destination service's documentation to determine the appropriate IAM roles to assign to the identity.Sinks that have a destination that is a log bucket in the same project as the sink cannot have a writer_identity and no additional permissions are required. Corresponds to the JSON property writerIdentity

Returns:

  • (String)


2919
2920
2921
# File 'lib/google/apis/logging_v2/classes.rb', line 2919

def writer_identity
  @writer_identity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
2939
2940
2941
# File 'lib/google/apis/logging_v2/classes.rb', line 2926

def update!(**args)
  @bigquery_options = args[:bigquery_options] if args.key?(:bigquery_options)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @destination = args[:destination] if args.key?(:destination)
  @disabled = args[:disabled] if args.key?(:disabled)
  @exclusions = args[:exclusions] if args.key?(:exclusions)
  @filter = args[:filter] if args.key?(:filter)
  @include_children = args[:include_children] if args.key?(:include_children)
  @intercept_children = args[:intercept_children] if args.key?(:intercept_children)
  @name = args[:name] if args.key?(:name)
  @output_version_format = args[:output_version_format] if args.key?(:output_version_format)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @writer_identity = args[:writer_identity] if args.key?(:writer_identity)
end