Class: Google::Apis::LoggingV2::LogSink
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::LogSink
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Describes a sink used to export log entries to one of the following destinations: a Cloud Logging log bucket, a Cloud Storage bucket, a BigQuery dataset, a Pub/Sub topic, a Cloud project.A logs filter controls which log entries are exported. The sink must be created within a project, organization, billing account, or folder.
Instance Attribute Summary collapse
-
#bigquery_options ⇒ Google::Apis::LoggingV2::BigQueryOptions
Options that change functionality of a sink exporting data to BigQuery.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#destination ⇒ String
Required.
-
#disabled ⇒ Boolean
(also: #disabled?)
Optional.
-
#exclusions ⇒ Array<Google::Apis::LoggingV2::LogExclusion>
Optional.
-
#filter ⇒ String
Optional.
-
#include_children ⇒ Boolean
(also: #include_children?)
Optional.
-
#intercept_children ⇒ Boolean
(also: #intercept_children?)
Optional.
-
#name ⇒ String
Optional.
-
#output_version_format ⇒ String
Deprecated.
-
#resource_name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#writer_identity ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LogSink
constructor
A new instance of LogSink.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LogSink
Returns a new instance of LogSink.
2711 2712 2713 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_options ⇒ Google::Apis::LoggingV2::BigQueryOptions
Options that change functionality of a sink exporting data to BigQuery.
Corresponds to the JSON property bigqueryOptions
2589 2590 2591 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2589 def @bigquery_options end |
#create_time ⇒ String
Output only. The creation timestamp of the sink.This field may not be present
for older sinks.
Corresponds to the JSON property createTime
2595 2596 2597 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2595 def create_time @create_time end |
#description ⇒ String
Optional. A description of this sink.The maximum length of the description is
8000 characters.
Corresponds to the JSON property description
2601 2602 2603 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2601 def description @description end |
#destination ⇒ String
Required. The export destination: "storage.googleapis.com/[GCS_BUCKET]" "
bigquery.googleapis.com/projects/[PROJECT_ID]/datasets/[DATASET]" "pubsub.
googleapis.com/projects/[PROJECT_ID]/topics/[TOPIC_ID]" "logging.googleapis.
com/projects/[PROJECT_ID]" "logging.googleapis.com/projects/[PROJECT_ID]/
locations/[LOCATION_ID]/buckets/[BUCKET_ID]" The sink's writer_identity, set
when the sink is created, must have permission to write to the destination or
else the log entries are not exported. For more information, see Exporting
Logs with Sinks (https://cloud.google.com/logging/docs/api/tasks/exporting-
logs).
Corresponds to the JSON property destination
2614 2615 2616 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2614 def destination @destination end |
#disabled ⇒ Boolean Also known as: disabled?
Optional. If set to true, then this sink is disabled and it does not export
any log entries.
Corresponds to the JSON property disabled
2620 2621 2622 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2620 def disabled @disabled end |
#exclusions ⇒ Array<Google::Apis::LoggingV2::LogExclusion>
Optional. Log entries that match any of these exclusion filters will not be
exported.If a log entry is matched by both filter and one of exclusions it
will not be exported.
Corresponds to the JSON property exclusions
2628 2629 2630 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2628 def exclusions @exclusions end |
#filter ⇒ String
Optional. An advanced logs filter (https://cloud.google.com/logging/docs/view/
advanced-queries). The only exported log entries are those that are in the
resource owning the sink and that match the filter.For example:logName="
projects/[PROJECT_ID]/logs/[LOG_ID]" AND severity>=ERROR
Corresponds to the JSON property filter
2636 2637 2638 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2636 def filter @filter end |
#include_children ⇒ Boolean Also known as: include_children?
Optional. This field applies only to sinks owned by organizations and folders.
If the field is false, the default, only the logs owned by the sink's parent
resource are available for export. If the field is true, then log entries from
all the projects, folders, and billing accounts contained in the sink's parent
resource are also available for export. Whether a particular log entry from
the children is exported depends on the sink's filter expression.For example,
if this field is true, then the filter resource.type=gce_instance would export
all Compute Engine VM instance log entries from all projects in the sink's
parent.To only export entries from certain child projects, filter on the
project part of the log name:logName:("projects/test-project1/" OR "projects/
test-project2/") AND resource.type=gce_instance
Corresponds to the JSON property includeChildren
2651 2652 2653 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2651 def include_children @include_children end |
#intercept_children ⇒ Boolean Also known as: intercept_children?
Optional. This field applies only to sinks owned by organizations and folders.
When the value of 'intercept_children' is true, the following restrictions
apply: The sink must have the include_children flag set to true. The sink
destination must be a Cloud project.Also, the following behaviors apply: Any
logs matched by the sink won't be included by non-_Required sinks owned by
child resources. The sink appears in the results of a ListSinks call from a
child resource if the value of the filter field in its request is either '
in_scope("ALL")' or 'in_scope("ANCESTOR")'.
Corresponds to the JSON property interceptChildren
2664 2665 2666 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2664 def intercept_children @intercept_children end |
#name ⇒ String
Optional. The client-assigned sink identifier, unique within the project.For
example: "my-syslog-errors-to-pubsub".Sink identifiers are limited to 100
characters and can include only the following characters: upper and lower-case
alphanumeric characters, underscores, hyphens, periods.First character has to
be alphanumeric.
Corresponds to the JSON property name
2674 2675 2676 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2674 def name @name end |
#output_version_format ⇒ String
Deprecated. This field is unused.
Corresponds to the JSON property outputVersionFormat
2679 2680 2681 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2679 def output_version_format @output_version_format end |
#resource_name ⇒ String
Output only. The resource name of the sink. "projects/[PROJECT_ID]/sinks/[
SINK_NAME] "organizations/[ORGANIZATION_ID]/sinks/[SINK_NAME] "billingAccounts/
[BILLING_ACCOUNT_ID]/sinks/[SINK_NAME] "folders/[FOLDER_ID]/sinks/[SINK_NAME]
For example: projects/my_project/sinks/SINK_NAME
Corresponds to the JSON property resourceName
2687 2688 2689 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2687 def resource_name @resource_name end |
#update_time ⇒ String
Output only. The last update timestamp of the sink.This field may not be
present for older sinks.
Corresponds to the JSON property updateTime
2693 2694 2695 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2693 def update_time @update_time end |
#writer_identity ⇒ String
Output only. An IAM identity—a service account or group—under which Cloud
Logging writes the exported log entries to the sink's destination. This field
is either set by specifying custom_writer_identity or set automatically by
sinks.create and sinks.update based on the value of unique_writer_identity in
those methods.Until you grant this identity write-access to the destination,
log entry exports from this sink will fail. For more information, see Granting
Access for a Resource (https://cloud.google.com/iam/docs/granting-roles-to-
service-accounts#granting_access_to_a_service_account_for_a_resource). Consult
the destination service's documentation to determine the appropriate IAM roles
to assign to the identity.Sinks that have a destination that is a log bucket
in the same project as the sink cannot have a writer_identity and no
additional permissions are required.
Corresponds to the JSON property writerIdentity
2709 2710 2711 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2709 def writer_identity @writer_identity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2716 def update!(**args) @bigquery_options = args[:bigquery_options] if args.key?(:bigquery_options) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @destination = args[:destination] if args.key?(:destination) @disabled = args[:disabled] if args.key?(:disabled) @exclusions = args[:exclusions] if args.key?(:exclusions) @filter = args[:filter] if args.key?(:filter) @include_children = args[:include_children] if args.key?(:include_children) @intercept_children = args[:intercept_children] if args.key?(:intercept_children) @name = args[:name] if args.key?(:name) @output_version_format = args[:output_version_format] if args.key?(:output_version_format) @resource_name = args[:resource_name] if args.key?(:resource_name) @update_time = args[:update_time] if args.key?(:update_time) @writer_identity = args[:writer_identity] if args.key?(:writer_identity) end |