Class: Google::Apis::LoggingV2::LogView
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::LogView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Describes a view over log entries in a bucket.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#filter ⇒ String
Optional.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LogView
constructor
A new instance of LogView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LogView
Returns a new instance of LogView.
3017 3018 3019 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The creation timestamp of the view.
Corresponds to the JSON property createTime
2987 2988 2989 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2987 def create_time @create_time end |
#description ⇒ String
Optional. Describes this view.
Corresponds to the JSON property description
2992 2993 2994 |
# File 'lib/google/apis/logging_v2/classes.rb', line 2992 def description @description end |
#filter ⇒ String
Optional. Filter that restricts which log entries in a bucket are visible in
this view.Filters must be logical conjunctions that use the AND operator, and
they can use any of the following qualifiers: SOURCE(), which specifies a
project, folder, organization, or billing account of origin. resource.type,
which specifies the resource type. LOG_ID(), which identifies the log.They can
also use the negations of these qualifiers with the NOT operator.For example:
SOURCE("projects/myproject") AND resource.type = "gce_instance" AND NOT LOG_ID(
"stdout")
Corresponds to the JSON property filter
3004 3005 3006 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3004 def filter @filter end |
#name ⇒ String
Output only. The resource name of the view.For example:projects/my-project/
locations/global/buckets/my-bucket/views/my-view
Corresponds to the JSON property name
3010 3011 3012 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3010 def name @name end |
#update_time ⇒ String
Output only. The last update timestamp of the view.
Corresponds to the JSON property updateTime
3015 3016 3017 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3015 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3022 3023 3024 3025 3026 3027 3028 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3022 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @filter = args[:filter] if args.key?(:filter) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |