Class: Google::Apis::LoggingV2::LogView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Describes a view over log entries in a bucket.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LogView

Returns a new instance of LogView.



2807
2808
2809
# File 'lib/google/apis/logging_v2/classes.rb', line 2807

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The creation timestamp of the view. Corresponds to the JSON property createTime

Returns:

  • (String)


2777
2778
2779
# File 'lib/google/apis/logging_v2/classes.rb', line 2777

def create_time
  @create_time
end

#descriptionString

Optional. Describes this view. Corresponds to the JSON property description

Returns:

  • (String)


2782
2783
2784
# File 'lib/google/apis/logging_v2/classes.rb', line 2782

def description
  @description
end

#filterString

Optional. Filter that restricts which log entries in a bucket are visible in this view.Filters must be logical conjunctions that use the AND operator, and they can use any of the following qualifiers: SOURCE(), which specifies a project, folder, organization, or billing account of origin. resource.type, which specifies the resource type. LOG_ID(), which identifies the log.They can also use the negations of these qualifiers with the NOT operator.For example: SOURCE("projects/myproject") AND resource.type = "gce_instance" AND NOT LOG_ID( "stdout") Corresponds to the JSON property filter

Returns:

  • (String)


2794
2795
2796
# File 'lib/google/apis/logging_v2/classes.rb', line 2794

def filter
  @filter
end

#nameString

Output only. The resource name of the view.For example:projects/my-project/ locations/global/buckets/my-bucket/views/my-view Corresponds to the JSON property name

Returns:

  • (String)


2800
2801
2802
# File 'lib/google/apis/logging_v2/classes.rb', line 2800

def name
  @name
end

#update_timeString

Output only. The last update timestamp of the view. Corresponds to the JSON property updateTime

Returns:

  • (String)


2805
2806
2807
# File 'lib/google/apis/logging_v2/classes.rb', line 2805

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2812
2813
2814
2815
2816
2817
2818
# File 'lib/google/apis/logging_v2/classes.rb', line 2812

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @filter = args[:filter] if args.key?(:filter)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end