Class: Google::Apis::LoggingV2::LoggingQuery
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::LoggingQuery
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Describes a Cloud Logging query that can be run in Logs Explorer UI or via the logging API.In addition to the query itself, additional information may be stored to capture the display configuration and other UI state used in association with analysis of query results.
Instance Attribute Summary collapse
-
#filter ⇒ String
Required.
-
#summary_field_end ⇒ Fixnum
Characters will be counted from the end of the string.
-
#summary_field_start ⇒ Fixnum
Characters will be counted from the start of the string.
-
#summary_fields ⇒ Array<Google::Apis::LoggingV2::SummaryField>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoggingQuery
constructor
A new instance of LoggingQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoggingQuery
Returns a new instance of LoggingQuery.
3054 3055 3056 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3054 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Required. An advanced query using the Logging Query Language (https://docs.
cloud.google.com/logging/docs/view/logging-query-language). The maximum length
of the filter is 20000 characters.
Corresponds to the JSON property filter
3037 3038 3039 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3037 def filter @filter end |
#summary_field_end ⇒ Fixnum
Characters will be counted from the end of the string.
Corresponds to the JSON property summaryFieldEnd
3042 3043 3044 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3042 def summary_field_end @summary_field_end end |
#summary_field_start ⇒ Fixnum
Characters will be counted from the start of the string.
Corresponds to the JSON property summaryFieldStart
3047 3048 3049 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3047 def summary_field_start @summary_field_start end |
#summary_fields ⇒ Array<Google::Apis::LoggingV2::SummaryField>
Optional. The set of summary fields to display for this saved query.
Corresponds to the JSON property summaryFields
3052 3053 3054 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3052 def summary_fields @summary_fields end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3059 3060 3061 3062 3063 3064 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3059 def update!(**args) @filter = args[:filter] if args.key?(:filter) @summary_field_end = args[:summary_field_end] if args.key?(:summary_field_end) @summary_field_start = args[:summary_field_start] if args.key?(:summary_field_start) @summary_fields = args[:summary_fields] if args.key?(:summary_fields) end |