Class: Google::Apis::LoggingV2::MetricDescriptorMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Additional annotations that can be used to guide the usage of a metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetricDescriptorMetadata

Returns a new instance of MetricDescriptorMetadata.



3242
3243
3244
# File 'lib/google/apis/logging_v2/classes.rb', line 3242

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ingest_delayString

The delay of data points caused by ingestion. Data points older than this age are guaranteed to be ingested and available to be read, excluding data loss due to errors. Corresponds to the JSON property ingestDelay

Returns:

  • (String)


3222
3223
3224
# File 'lib/google/apis/logging_v2/classes.rb', line 3222

def ingest_delay
  @ingest_delay
end

#launch_stageString

Deprecated. Must use the MetricDescriptor.launch_stage instead. Corresponds to the JSON property launchStage

Returns:

  • (String)


3227
3228
3229
# File 'lib/google/apis/logging_v2/classes.rb', line 3227

def launch_stage
  @launch_stage
end

#sample_periodString

The sampling period of metric data points. For metrics which are written periodically, consecutive data points are stored at this time interval, excluding data loss due to errors. Metrics with a higher granularity have a smaller sampling period. Corresponds to the JSON property samplePeriod

Returns:

  • (String)


3235
3236
3237
# File 'lib/google/apis/logging_v2/classes.rb', line 3235

def sample_period
  @sample_period
end

#time_series_resource_hierarchy_levelArray<String>

The scope of the timeseries data of the metric. Corresponds to the JSON property timeSeriesResourceHierarchyLevel

Returns:

  • (Array<String>)


3240
3241
3242
# File 'lib/google/apis/logging_v2/classes.rb', line 3240

def time_series_resource_hierarchy_level
  @time_series_resource_hierarchy_level
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3247
3248
3249
3250
3251
3252
# File 'lib/google/apis/logging_v2/classes.rb', line 3247

def update!(**args)
  @ingest_delay = args[:ingest_delay] if args.key?(:ingest_delay)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @sample_period = args[:sample_period] if args.key?(:sample_period)
  @time_series_resource_hierarchy_level = args[:time_series_resource_hierarchy_level] if args.key?(:time_series_resource_hierarchy_level)
end