Class: Google::Apis::LoggingV2::OpsAnalyticsQuery
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::OpsAnalyticsQuery
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Describes an analytics query that can be run in the Log Analytics page of Google Cloud console.Preview: This is a preview feature and may be subject to change before final release.
Instance Attribute Summary collapse
-
#sql_query_text ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OpsAnalyticsQuery
constructor
A new instance of OpsAnalyticsQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OpsAnalyticsQuery
Returns a new instance of OpsAnalyticsQuery.
3261 3262 3263 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3261 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sql_query_text ⇒ String
Required. A logs analytics SQL query, which generally follows BigQuery format.
This is the SQL query that appears in the Log Analytics UI's query editor.
Corresponds to the JSON property sqlQueryText
3259 3260 3261 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3259 def sql_query_text @sql_query_text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3266 3267 3268 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3266 def update!(**args) @sql_query_text = args[:sql_query_text] if args.key?(:sql_query_text) end |