Class: Google::Apis::LoggingV2::RecentQuery
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::RecentQuery
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Describes a recent query executed on the Logs Explorer or Log Analytics page within the last ~ 30 days.
Instance Attribute Summary collapse
-
#last_run_time ⇒ String
Output only.
-
#logging_query ⇒ Google::Apis::LoggingV2::LoggingQuery
Describes a Cloud Logging query that can be run in Logs Explorer UI or via the logging API.In addition to the query itself, additional information may be stored to capture the display configuration and other UI state used in association with analysis of query results.
-
#name ⇒ String
Output only.
-
#ops_analytics_query ⇒ Google::Apis::LoggingV2::OpsAnalyticsQuery
Describes a query that can be run in Log Analytics.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecentQuery
constructor
A new instance of RecentQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecentQuery
Returns a new instance of RecentQuery.
3749 3750 3751 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3749 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_run_time ⇒ String
Output only. The timestamp when this query was last run.
Corresponds to the JSON property lastRunTime
3726 3727 3728 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3726 def last_run_time @last_run_time end |
#logging_query ⇒ Google::Apis::LoggingV2::LoggingQuery
Describes a Cloud Logging query that can be run in Logs Explorer UI or via the
logging API.In addition to the query itself, additional information may be
stored to capture the display configuration and other UI state used in
association with analysis of query results.
Corresponds to the JSON property loggingQuery
3734 3735 3736 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3734 def logging_query @logging_query end |
#name ⇒ String
Output only. Resource name of the recent query.In the format: "projects/[
PROJECT_ID]/locations/[LOCATION_ID]/recentQueries/[QUERY_ID]" For a list of
supported locations, see Supported Regions (https://docs.cloud.google.com/
logging/docs/region-support)The QUERY_ID is a system generated alphanumeric ID.
Corresponds to the JSON property name
3742 3743 3744 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3742 def name @name end |
#ops_analytics_query ⇒ Google::Apis::LoggingV2::OpsAnalyticsQuery
Describes a query that can be run in Log Analytics.
Corresponds to the JSON property opsAnalyticsQuery
3747 3748 3749 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3747 def ops_analytics_query @ops_analytics_query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3754 3755 3756 3757 3758 3759 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3754 def update!(**args) @last_run_time = args[:last_run_time] if args.key?(:last_run_time) @logging_query = args[:logging_query] if args.key?(:logging_query) @name = args[:name] if args.key?(:name) @ops_analytics_query = args[:ops_analytics_query] if args.key?(:ops_analytics_query) end |