Class: Google::Apis::LoggingV2::RecentQuery
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::RecentQuery
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Describes a recent query executed on the Logs Explorer or Log Analytics page within the last ~ 30 days.
Instance Attribute Summary collapse
-
#last_run_time ⇒ String
Output only.
-
#logging_query ⇒ Google::Apis::LoggingV2::LoggingQuery
Describes a Cloud Logging query that can be run in Logs Explorer UI or via the logging API.In addition to the query itself, additional information may be stored to capture the display configuration and other UI state used in association with analysis of query results.
-
#name ⇒ String
Output only.
-
#ops_analytics_query ⇒ Google::Apis::LoggingV2::OpsAnalyticsQuery
Describes an analytics query that can be run in the Log Analytics page of Google Cloud console.Preview: This is a preview feature and may be subject to change before final release.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecentQuery
constructor
A new instance of RecentQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecentQuery
Returns a new instance of RecentQuery.
3391 3392 3393 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3391 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_run_time ⇒ String
Output only. The timestamp when this query was last run.
Corresponds to the JSON property lastRunTime
3366 3367 3368 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3366 def last_run_time @last_run_time end |
#logging_query ⇒ Google::Apis::LoggingV2::LoggingQuery
Describes a Cloud Logging query that can be run in Logs Explorer UI or via the
logging API.In addition to the query itself, additional information may be
stored to capture the display configuration and other UI state used in
association with analysis of query results.
Corresponds to the JSON property loggingQuery
3374 3375 3376 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3374 def logging_query @logging_query end |
#name ⇒ String
Output only. Resource name of the recent query.In the format: "projects/[
PROJECT_ID]/locations/[LOCATION_ID]/recentQueries/[QUERY_ID]" For a list of
supported locations, see Supported Regions (https://cloud.google.com/logging/
docs/region-support)The QUERY_ID is a system generated alphanumeric ID.
Corresponds to the JSON property name
3382 3383 3384 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3382 def name @name end |
#ops_analytics_query ⇒ Google::Apis::LoggingV2::OpsAnalyticsQuery
Describes an analytics query that can be run in the Log Analytics page of
Google Cloud console.Preview: This is a preview feature and may be subject to
change before final release.
Corresponds to the JSON property opsAnalyticsQuery
3389 3390 3391 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3389 def ops_analytics_query @ops_analytics_query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3396 3397 3398 3399 3400 3401 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3396 def update!(**args) @last_run_time = args[:last_run_time] if args.key?(:last_run_time) @logging_query = args[:logging_query] if args.key?(:logging_query) @name = args[:name] if args.key?(:name) @ops_analytics_query = args[:ops_analytics_query] if args.key?(:ops_analytics_query) end |