Class: Google::Apis::LoggingV2::RequestLog

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Complete log information about a single HTTP request to an App Engine application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RequestLog

Returns a new instance of RequestLog.



3973
3974
3975
# File 'lib/google/apis/logging_v2/classes.rb', line 3973

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_engine_releaseString

App Engine release version. Corresponds to the JSON property appEngineRelease

Returns:

  • (String)


3787
3788
3789
# File 'lib/google/apis/logging_v2/classes.rb', line 3787

def app_engine_release
  @app_engine_release
end

#app_idString

Application that handled this request. Corresponds to the JSON property appId

Returns:

  • (String)


3792
3793
3794
# File 'lib/google/apis/logging_v2/classes.rb', line 3792

def app_id
  @app_id
end

#costFloat

An indication of the relative cost of serving this request. Corresponds to the JSON property cost

Returns:

  • (Float)


3797
3798
3799
# File 'lib/google/apis/logging_v2/classes.rb', line 3797

def cost
  @cost
end

#end_timeString

Time when the request finished. Corresponds to the JSON property endTime

Returns:

  • (String)


3802
3803
3804
# File 'lib/google/apis/logging_v2/classes.rb', line 3802

def end_time
  @end_time
end

#finishedBoolean Also known as: finished?

Whether this request is finished or active. Corresponds to the JSON property finished

Returns:

  • (Boolean)


3807
3808
3809
# File 'lib/google/apis/logging_v2/classes.rb', line 3807

def finished
  @finished
end

#firstBoolean Also known as: first?

Whether this is the first RequestLog entry for this request. If an active request has several RequestLog entries written to Stackdriver Logging, then this field will be set for one of them. Corresponds to the JSON property first

Returns:

  • (Boolean)


3815
3816
3817
# File 'lib/google/apis/logging_v2/classes.rb', line 3815

def first
  @first
end

#hostString

Internet host and port number of the resource being requested. Corresponds to the JSON property host

Returns:

  • (String)


3821
3822
3823
# File 'lib/google/apis/logging_v2/classes.rb', line 3821

def host
  @host
end

#http_versionString

HTTP version of request. Example: "HTTP/1.1". Corresponds to the JSON property httpVersion

Returns:

  • (String)


3826
3827
3828
# File 'lib/google/apis/logging_v2/classes.rb', line 3826

def http_version
  @http_version
end

#instance_idString

An identifier for the instance that handled the request. Corresponds to the JSON property instanceId

Returns:

  • (String)


3831
3832
3833
# File 'lib/google/apis/logging_v2/classes.rb', line 3831

def instance_id
  @instance_id
end

#instance_indexFixnum

If the instance processing this request belongs to a manually scaled module, then this is the 0-based index of the instance. Otherwise, this value is -1. Corresponds to the JSON property instanceIndex

Returns:

  • (Fixnum)


3837
3838
3839
# File 'lib/google/apis/logging_v2/classes.rb', line 3837

def instance_index
  @instance_index
end

#ipString

Origin IP address. Corresponds to the JSON property ip

Returns:

  • (String)


3842
3843
3844
# File 'lib/google/apis/logging_v2/classes.rb', line 3842

def ip
  @ip
end

#latencyString

Latency of the request. Corresponds to the JSON property latency

Returns:

  • (String)


3847
3848
3849
# File 'lib/google/apis/logging_v2/classes.rb', line 3847

def latency
  @latency
end

#lineArray<Google::Apis::LoggingV2::LogLine>

A list of log lines emitted by the application while serving this request. Corresponds to the JSON property line



3852
3853
3854
# File 'lib/google/apis/logging_v2/classes.rb', line 3852

def line
  @line
end

#mega_cyclesFixnum

Number of CPU megacycles used to process request. Corresponds to the JSON property megaCycles

Returns:

  • (Fixnum)


3857
3858
3859
# File 'lib/google/apis/logging_v2/classes.rb', line 3857

def mega_cycles
  @mega_cycles
end

#method_propString

Request method. Example: "GET", "HEAD", "PUT", "POST", "DELETE". Corresponds to the JSON property method

Returns:

  • (String)


3862
3863
3864
# File 'lib/google/apis/logging_v2/classes.rb', line 3862

def method_prop
  @method_prop
end

#module_idString

Module of the application that handled this request. Corresponds to the JSON property moduleId

Returns:

  • (String)


3867
3868
3869
# File 'lib/google/apis/logging_v2/classes.rb', line 3867

def module_id
  @module_id
end

#nicknameString

The logged-in user who made the request.Most likely, this is the part of the user's email before the @ sign. The field value is the same for different requests from the same user, but different users can have similar names. This information is also available to the application via the App Engine Users API. This field will be populated starting with App Engine 1.9.21. Corresponds to the JSON property nickname

Returns:

  • (String)


3876
3877
3878
# File 'lib/google/apis/logging_v2/classes.rb', line 3876

def nickname
  @nickname
end

#pending_timeString

Time this request spent in the pending request queue. Corresponds to the JSON property pendingTime

Returns:

  • (String)


3881
3882
3883
# File 'lib/google/apis/logging_v2/classes.rb', line 3881

def pending_time
  @pending_time
end

#referrerString

Referrer URL of request. Corresponds to the JSON property referrer

Returns:

  • (String)


3886
3887
3888
# File 'lib/google/apis/logging_v2/classes.rb', line 3886

def referrer
  @referrer
end

#request_idString

Globally unique identifier for a request, which is based on the request start time. Request IDs for requests which started later will compare greater as strings than those for requests which started earlier. Corresponds to the JSON property requestId

Returns:

  • (String)


3893
3894
3895
# File 'lib/google/apis/logging_v2/classes.rb', line 3893

def request_id
  @request_id
end

#resourceString

Contains the path and query portion of the URL that was requested. For example, if the URL was "http://example.com/app?name=val", the resource would be "/app? name=val". The fragment identifier, which is identified by the # character, is not included. Corresponds to the JSON property resource

Returns:

  • (String)


3901
3902
3903
# File 'lib/google/apis/logging_v2/classes.rb', line 3901

def resource
  @resource
end

#response_sizeFixnum

Size in bytes sent back to client by request. Corresponds to the JSON property responseSize

Returns:

  • (Fixnum)


3906
3907
3908
# File 'lib/google/apis/logging_v2/classes.rb', line 3906

def response_size
  @response_size
end

#source_referenceArray<Google::Apis::LoggingV2::SourceReference>

Source code for the application that handled this request. There can be more than one source reference per deployed application if source code is distributed among multiple repositories. Corresponds to the JSON property sourceReference



3913
3914
3915
# File 'lib/google/apis/logging_v2/classes.rb', line 3913

def source_reference
  @source_reference
end

#span_idString

Stackdriver Trace span identifier for this request. Corresponds to the JSON property spanId

Returns:

  • (String)


3918
3919
3920
# File 'lib/google/apis/logging_v2/classes.rb', line 3918

def span_id
  @span_id
end

#start_timeString

Time when the request started. Corresponds to the JSON property startTime

Returns:

  • (String)


3923
3924
3925
# File 'lib/google/apis/logging_v2/classes.rb', line 3923

def start_time
  @start_time
end

#statusFixnum

HTTP response status code. Example: 200, 404. Corresponds to the JSON property status

Returns:

  • (Fixnum)


3928
3929
3930
# File 'lib/google/apis/logging_v2/classes.rb', line 3928

def status
  @status
end

#task_nameString

Task name of the request, in the case of an offline request. Corresponds to the JSON property taskName

Returns:

  • (String)


3933
3934
3935
# File 'lib/google/apis/logging_v2/classes.rb', line 3933

def task_name
  @task_name
end

#task_queue_nameString

Queue name of the request, in the case of an offline request. Corresponds to the JSON property taskQueueName

Returns:

  • (String)


3938
3939
3940
# File 'lib/google/apis/logging_v2/classes.rb', line 3938

def task_queue_name
  @task_queue_name
end

#trace_idString

Stackdriver Trace identifier for this request. Corresponds to the JSON property traceId

Returns:

  • (String)


3943
3944
3945
# File 'lib/google/apis/logging_v2/classes.rb', line 3943

def trace_id
  @trace_id
end

#trace_sampledBoolean Also known as: trace_sampled?

If true, the value in the 'trace_id' field was sampled for storage in a trace backend. Corresponds to the JSON property traceSampled

Returns:

  • (Boolean)


3949
3950
3951
# File 'lib/google/apis/logging_v2/classes.rb', line 3949

def trace_sampled
  @trace_sampled
end

#url_map_entryString

File or class that handled the request. Corresponds to the JSON property urlMapEntry

Returns:

  • (String)


3955
3956
3957
# File 'lib/google/apis/logging_v2/classes.rb', line 3955

def url_map_entry
  @url_map_entry
end

#user_agentString

User agent that made the request. Corresponds to the JSON property userAgent

Returns:

  • (String)


3960
3961
3962
# File 'lib/google/apis/logging_v2/classes.rb', line 3960

def user_agent
  @user_agent
end

#version_idString

Version of the application that handled this request. Corresponds to the JSON property versionId

Returns:

  • (String)


3965
3966
3967
# File 'lib/google/apis/logging_v2/classes.rb', line 3965

def version_id
  @version_id
end

#was_loading_requestBoolean Also known as: was_loading_request?

Whether this was a loading request for the instance. Corresponds to the JSON property wasLoadingRequest

Returns:

  • (Boolean)


3970
3971
3972
# File 'lib/google/apis/logging_v2/classes.rb', line 3970

def was_loading_request
  @was_loading_request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
# File 'lib/google/apis/logging_v2/classes.rb', line 3978

def update!(**args)
  @app_engine_release = args[:app_engine_release] if args.key?(:app_engine_release)
  @app_id = args[:app_id] if args.key?(:app_id)
  @cost = args[:cost] if args.key?(:cost)
  @end_time = args[:end_time] if args.key?(:end_time)
  @finished = args[:finished] if args.key?(:finished)
  @first = args[:first] if args.key?(:first)
  @host = args[:host] if args.key?(:host)
  @http_version = args[:http_version] if args.key?(:http_version)
  @instance_id = args[:instance_id] if args.key?(:instance_id)
  @instance_index = args[:instance_index] if args.key?(:instance_index)
  @ip = args[:ip] if args.key?(:ip)
  @latency = args[:latency] if args.key?(:latency)
  @line = args[:line] if args.key?(:line)
  @mega_cycles = args[:mega_cycles] if args.key?(:mega_cycles)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @module_id = args[:module_id] if args.key?(:module_id)
  @nickname = args[:nickname] if args.key?(:nickname)
  @pending_time = args[:pending_time] if args.key?(:pending_time)
  @referrer = args[:referrer] if args.key?(:referrer)
  @request_id = args[:request_id] if args.key?(:request_id)
  @resource = args[:resource] if args.key?(:resource)
  @response_size = args[:response_size] if args.key?(:response_size)
  @source_reference = args[:source_reference] if args.key?(:source_reference)
  @span_id = args[:span_id] if args.key?(:span_id)
  @start_time = args[:start_time] if args.key?(:start_time)
  @status = args[:status] if args.key?(:status)
  @task_name = args[:task_name] if args.key?(:task_name)
  @task_queue_name = args[:task_queue_name] if args.key?(:task_queue_name)
  @trace_id = args[:trace_id] if args.key?(:trace_id)
  @trace_sampled = args[:trace_sampled] if args.key?(:trace_sampled)
  @url_map_entry = args[:url_map_entry] if args.key?(:url_map_entry)
  @user_agent = args[:user_agent] if args.key?(:user_agent)
  @version_id = args[:version_id] if args.key?(:version_id)
  @was_loading_request = args[:was_loading_request] if args.key?(:was_loading_request)
end