Class: Google::Apis::LoggingV2::RequestLog
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::RequestLog
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Complete log information about a single HTTP request to an App Engine application.
Instance Attribute Summary collapse
-
#app_engine_release ⇒ String
App Engine release version.
-
#app_id ⇒ String
Application that handled this request.
-
#cost ⇒ Float
An indication of the relative cost of serving this request.
-
#end_time ⇒ String
Time when the request finished.
-
#finished ⇒ Boolean
(also: #finished?)
Whether this request is finished or active.
-
#first ⇒ Boolean
(also: #first?)
Whether this is the first RequestLog entry for this request.
-
#host ⇒ String
Internet host and port number of the resource being requested.
-
#http_version ⇒ String
HTTP version of request.
-
#instance_id ⇒ String
An identifier for the instance that handled the request.
-
#instance_index ⇒ Fixnum
If the instance processing this request belongs to a manually scaled module, then this is the 0-based index of the instance.
-
#ip ⇒ String
Origin IP address.
-
#latency ⇒ String
Latency of the request.
-
#line ⇒ Array<Google::Apis::LoggingV2::LogLine>
A list of log lines emitted by the application while serving this request.
-
#mega_cycles ⇒ Fixnum
Number of CPU megacycles used to process request.
-
#method_prop ⇒ String
Request method.
-
#module_id ⇒ String
Module of the application that handled this request.
-
#nickname ⇒ String
The logged-in user who made the request.Most likely, this is the part of the user's email before the @ sign.
-
#pending_time ⇒ String
Time this request spent in the pending request queue.
-
#referrer ⇒ String
Referrer URL of request.
-
#request_id ⇒ String
Globally unique identifier for a request, which is based on the request start time.
-
#resource ⇒ String
Contains the path and query portion of the URL that was requested.
-
#response_size ⇒ Fixnum
Size in bytes sent back to client by request.
-
#source_reference ⇒ Array<Google::Apis::LoggingV2::SourceReference>
Source code for the application that handled this request.
-
#span_id ⇒ String
Stackdriver Trace span identifier for this request.
-
#start_time ⇒ String
Time when the request started.
-
#status ⇒ Fixnum
HTTP response status code.
-
#task_name ⇒ String
Task name of the request, in the case of an offline request.
-
#task_queue_name ⇒ String
Queue name of the request, in the case of an offline request.
-
#trace_id ⇒ String
Stackdriver Trace identifier for this request.
-
#trace_sampled ⇒ Boolean
(also: #trace_sampled?)
If true, the value in the 'trace_id' field was sampled for storage in a trace backend.
-
#url_map_entry ⇒ String
File or class that handled the request.
-
#user_agent ⇒ String
User agent that made the request.
-
#version_id ⇒ String
Version of the application that handled this request.
-
#was_loading_request ⇒ Boolean
(also: #was_loading_request?)
Whether this was a loading request for the instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RequestLog
constructor
A new instance of RequestLog.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RequestLog
Returns a new instance of RequestLog.
3950 3951 3952 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3950 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_engine_release ⇒ String
App Engine release version.
Corresponds to the JSON property appEngineRelease
3764 3765 3766 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3764 def app_engine_release @app_engine_release end |
#app_id ⇒ String
Application that handled this request.
Corresponds to the JSON property appId
3769 3770 3771 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3769 def app_id @app_id end |
#cost ⇒ Float
An indication of the relative cost of serving this request.
Corresponds to the JSON property cost
3774 3775 3776 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3774 def cost @cost end |
#end_time ⇒ String
Time when the request finished.
Corresponds to the JSON property endTime
3779 3780 3781 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3779 def end_time @end_time end |
#finished ⇒ Boolean Also known as: finished?
Whether this request is finished or active.
Corresponds to the JSON property finished
3784 3785 3786 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3784 def finished @finished end |
#first ⇒ Boolean Also known as: first?
Whether this is the first RequestLog entry for this request. If an active
request has several RequestLog entries written to Stackdriver Logging, then
this field will be set for one of them.
Corresponds to the JSON property first
3792 3793 3794 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3792 def first @first end |
#host ⇒ String
Internet host and port number of the resource being requested.
Corresponds to the JSON property host
3798 3799 3800 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3798 def host @host end |
#http_version ⇒ String
HTTP version of request. Example: "HTTP/1.1".
Corresponds to the JSON property httpVersion
3803 3804 3805 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3803 def http_version @http_version end |
#instance_id ⇒ String
An identifier for the instance that handled the request.
Corresponds to the JSON property instanceId
3808 3809 3810 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3808 def instance_id @instance_id end |
#instance_index ⇒ Fixnum
If the instance processing this request belongs to a manually scaled module,
then this is the 0-based index of the instance. Otherwise, this value is -1.
Corresponds to the JSON property instanceIndex
3814 3815 3816 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3814 def instance_index @instance_index end |
#ip ⇒ String
Origin IP address.
Corresponds to the JSON property ip
3819 3820 3821 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3819 def ip @ip end |
#latency ⇒ String
Latency of the request.
Corresponds to the JSON property latency
3824 3825 3826 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3824 def latency @latency end |
#line ⇒ Array<Google::Apis::LoggingV2::LogLine>
A list of log lines emitted by the application while serving this request.
Corresponds to the JSON property line
3829 3830 3831 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3829 def line @line end |
#mega_cycles ⇒ Fixnum
Number of CPU megacycles used to process request.
Corresponds to the JSON property megaCycles
3834 3835 3836 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3834 def mega_cycles @mega_cycles end |
#method_prop ⇒ String
Request method. Example: "GET", "HEAD", "PUT", "POST", "DELETE".
Corresponds to the JSON property method
3839 3840 3841 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3839 def method_prop @method_prop end |
#module_id ⇒ String
Module of the application that handled this request.
Corresponds to the JSON property moduleId
3844 3845 3846 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3844 def module_id @module_id end |
#nickname ⇒ String
The logged-in user who made the request.Most likely, this is the part of the
user's email before the @ sign. The field value is the same for different
requests from the same user, but different users can have similar names. This
information is also available to the application via the App Engine Users API.
This field will be populated starting with App Engine 1.9.21.
Corresponds to the JSON property nickname
3853 3854 3855 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3853 def nickname @nickname end |
#pending_time ⇒ String
Time this request spent in the pending request queue.
Corresponds to the JSON property pendingTime
3858 3859 3860 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3858 def pending_time @pending_time end |
#referrer ⇒ String
Referrer URL of request.
Corresponds to the JSON property referrer
3863 3864 3865 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3863 def referrer @referrer end |
#request_id ⇒ String
Globally unique identifier for a request, which is based on the request start
time. Request IDs for requests which started later will compare greater as
strings than those for requests which started earlier.
Corresponds to the JSON property requestId
3870 3871 3872 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3870 def request_id @request_id end |
#resource ⇒ String
Contains the path and query portion of the URL that was requested. For example,
if the URL was "http://example.com/app?name=val", the resource would be "/app?
name=val". The fragment identifier, which is identified by the # character, is
not included.
Corresponds to the JSON property resource
3878 3879 3880 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3878 def resource @resource end |
#response_size ⇒ Fixnum
Size in bytes sent back to client by request.
Corresponds to the JSON property responseSize
3883 3884 3885 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3883 def response_size @response_size end |
#source_reference ⇒ Array<Google::Apis::LoggingV2::SourceReference>
Source code for the application that handled this request. There can be more
than one source reference per deployed application if source code is
distributed among multiple repositories.
Corresponds to the JSON property sourceReference
3890 3891 3892 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3890 def source_reference @source_reference end |
#span_id ⇒ String
Stackdriver Trace span identifier for this request.
Corresponds to the JSON property spanId
3895 3896 3897 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3895 def span_id @span_id end |
#start_time ⇒ String
Time when the request started.
Corresponds to the JSON property startTime
3900 3901 3902 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3900 def start_time @start_time end |
#status ⇒ Fixnum
HTTP response status code. Example: 200, 404.
Corresponds to the JSON property status
3905 3906 3907 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3905 def status @status end |
#task_name ⇒ String
Task name of the request, in the case of an offline request.
Corresponds to the JSON property taskName
3910 3911 3912 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3910 def task_name @task_name end |
#task_queue_name ⇒ String
Queue name of the request, in the case of an offline request.
Corresponds to the JSON property taskQueueName
3915 3916 3917 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3915 def task_queue_name @task_queue_name end |
#trace_id ⇒ String
Stackdriver Trace identifier for this request.
Corresponds to the JSON property traceId
3920 3921 3922 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3920 def trace_id @trace_id end |
#trace_sampled ⇒ Boolean Also known as: trace_sampled?
If true, the value in the 'trace_id' field was sampled for storage in a trace
backend.
Corresponds to the JSON property traceSampled
3926 3927 3928 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3926 def trace_sampled @trace_sampled end |
#url_map_entry ⇒ String
File or class that handled the request.
Corresponds to the JSON property urlMapEntry
3932 3933 3934 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3932 def url_map_entry @url_map_entry end |
#user_agent ⇒ String
User agent that made the request.
Corresponds to the JSON property userAgent
3937 3938 3939 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3937 def user_agent @user_agent end |
#version_id ⇒ String
Version of the application that handled this request.
Corresponds to the JSON property versionId
3942 3943 3944 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3942 def version_id @version_id end |
#was_loading_request ⇒ Boolean Also known as: was_loading_request?
Whether this was a loading request for the instance.
Corresponds to the JSON property wasLoadingRequest
3947 3948 3949 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3947 def was_loading_request @was_loading_request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3955 3956 3957 3958 3959 3960 3961 3962 3963 3964 3965 3966 3967 3968 3969 3970 3971 3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 3984 3985 3986 3987 3988 3989 3990 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3955 def update!(**args) @app_engine_release = args[:app_engine_release] if args.key?(:app_engine_release) @app_id = args[:app_id] if args.key?(:app_id) @cost = args[:cost] if args.key?(:cost) @end_time = args[:end_time] if args.key?(:end_time) @finished = args[:finished] if args.key?(:finished) @first = args[:first] if args.key?(:first) @host = args[:host] if args.key?(:host) @http_version = args[:http_version] if args.key?(:http_version) @instance_id = args[:instance_id] if args.key?(:instance_id) @instance_index = args[:instance_index] if args.key?(:instance_index) @ip = args[:ip] if args.key?(:ip) @latency = args[:latency] if args.key?(:latency) @line = args[:line] if args.key?(:line) @mega_cycles = args[:mega_cycles] if args.key?(:mega_cycles) @method_prop = args[:method_prop] if args.key?(:method_prop) @module_id = args[:module_id] if args.key?(:module_id) @nickname = args[:nickname] if args.key?(:nickname) @pending_time = args[:pending_time] if args.key?(:pending_time) @referrer = args[:referrer] if args.key?(:referrer) @request_id = args[:request_id] if args.key?(:request_id) @resource = args[:resource] if args.key?(:resource) @response_size = args[:response_size] if args.key?(:response_size) @source_reference = args[:source_reference] if args.key?(:source_reference) @span_id = args[:span_id] if args.key?(:span_id) @start_time = args[:start_time] if args.key?(:start_time) @status = args[:status] if args.key?(:status) @task_name = args[:task_name] if args.key?(:task_name) @task_queue_name = args[:task_queue_name] if args.key?(:task_queue_name) @trace_id = args[:trace_id] if args.key?(:trace_id) @trace_sampled = args[:trace_sampled] if args.key?(:trace_sampled) @url_map_entry = args[:url_map_entry] if args.key?(:url_map_entry) @user_agent = args[:user_agent] if args.key?(:user_agent) @version_id = args[:version_id] if args.key?(:version_id) @was_loading_request = args[:was_loading_request] if args.key?(:was_loading_request) end |