Class: Google::Apis::LoggingV2::RequestLog

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Complete log information about a single HTTP request to an App Engine application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RequestLog

Returns a new instance of RequestLog.



3598
3599
3600
# File 'lib/google/apis/logging_v2/classes.rb', line 3598

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_engine_releaseString

App Engine release version. Corresponds to the JSON property appEngineRelease

Returns:

  • (String)


3412
3413
3414
# File 'lib/google/apis/logging_v2/classes.rb', line 3412

def app_engine_release
  @app_engine_release
end

#app_idString

Application that handled this request. Corresponds to the JSON property appId

Returns:

  • (String)


3417
3418
3419
# File 'lib/google/apis/logging_v2/classes.rb', line 3417

def app_id
  @app_id
end

#costFloat

An indication of the relative cost of serving this request. Corresponds to the JSON property cost

Returns:

  • (Float)


3422
3423
3424
# File 'lib/google/apis/logging_v2/classes.rb', line 3422

def cost
  @cost
end

#end_timeString

Time when the request finished. Corresponds to the JSON property endTime

Returns:

  • (String)


3427
3428
3429
# File 'lib/google/apis/logging_v2/classes.rb', line 3427

def end_time
  @end_time
end

#finishedBoolean Also known as: finished?

Whether this request is finished or active. Corresponds to the JSON property finished

Returns:

  • (Boolean)


3432
3433
3434
# File 'lib/google/apis/logging_v2/classes.rb', line 3432

def finished
  @finished
end

#firstBoolean Also known as: first?

Whether this is the first RequestLog entry for this request. If an active request has several RequestLog entries written to Stackdriver Logging, then this field will be set for one of them. Corresponds to the JSON property first

Returns:

  • (Boolean)


3440
3441
3442
# File 'lib/google/apis/logging_v2/classes.rb', line 3440

def first
  @first
end

#hostString

Internet host and port number of the resource being requested. Corresponds to the JSON property host

Returns:

  • (String)


3446
3447
3448
# File 'lib/google/apis/logging_v2/classes.rb', line 3446

def host
  @host
end

#http_versionString

HTTP version of request. Example: "HTTP/1.1". Corresponds to the JSON property httpVersion

Returns:

  • (String)


3451
3452
3453
# File 'lib/google/apis/logging_v2/classes.rb', line 3451

def http_version
  @http_version
end

#instance_idString

An identifier for the instance that handled the request. Corresponds to the JSON property instanceId

Returns:

  • (String)


3456
3457
3458
# File 'lib/google/apis/logging_v2/classes.rb', line 3456

def instance_id
  @instance_id
end

#instance_indexFixnum

If the instance processing this request belongs to a manually scaled module, then this is the 0-based index of the instance. Otherwise, this value is -1. Corresponds to the JSON property instanceIndex

Returns:

  • (Fixnum)


3462
3463
3464
# File 'lib/google/apis/logging_v2/classes.rb', line 3462

def instance_index
  @instance_index
end

#ipString

Origin IP address. Corresponds to the JSON property ip

Returns:

  • (String)


3467
3468
3469
# File 'lib/google/apis/logging_v2/classes.rb', line 3467

def ip
  @ip
end

#latencyString

Latency of the request. Corresponds to the JSON property latency

Returns:

  • (String)


3472
3473
3474
# File 'lib/google/apis/logging_v2/classes.rb', line 3472

def latency
  @latency
end

#lineArray<Google::Apis::LoggingV2::LogLine>

A list of log lines emitted by the application while serving this request. Corresponds to the JSON property line



3477
3478
3479
# File 'lib/google/apis/logging_v2/classes.rb', line 3477

def line
  @line
end

#mega_cyclesFixnum

Number of CPU megacycles used to process request. Corresponds to the JSON property megaCycles

Returns:

  • (Fixnum)


3482
3483
3484
# File 'lib/google/apis/logging_v2/classes.rb', line 3482

def mega_cycles
  @mega_cycles
end

#method_propString

Request method. Example: "GET", "HEAD", "PUT", "POST", "DELETE". Corresponds to the JSON property method

Returns:

  • (String)


3487
3488
3489
# File 'lib/google/apis/logging_v2/classes.rb', line 3487

def method_prop
  @method_prop
end

#module_idString

Module of the application that handled this request. Corresponds to the JSON property moduleId

Returns:

  • (String)


3492
3493
3494
# File 'lib/google/apis/logging_v2/classes.rb', line 3492

def module_id
  @module_id
end

#nicknameString

The logged-in user who made the request.Most likely, this is the part of the user's email before the @ sign. The field value is the same for different requests from the same user, but different users can have similar names. This information is also available to the application via the App Engine Users API. This field will be populated starting with App Engine 1.9.21. Corresponds to the JSON property nickname

Returns:

  • (String)


3501
3502
3503
# File 'lib/google/apis/logging_v2/classes.rb', line 3501

def nickname
  @nickname
end

#pending_timeString

Time this request spent in the pending request queue. Corresponds to the JSON property pendingTime

Returns:

  • (String)


3506
3507
3508
# File 'lib/google/apis/logging_v2/classes.rb', line 3506

def pending_time
  @pending_time
end

#referrerString

Referrer URL of request. Corresponds to the JSON property referrer

Returns:

  • (String)


3511
3512
3513
# File 'lib/google/apis/logging_v2/classes.rb', line 3511

def referrer
  @referrer
end

#request_idString

Globally unique identifier for a request, which is based on the request start time. Request IDs for requests which started later will compare greater as strings than those for requests which started earlier. Corresponds to the JSON property requestId

Returns:

  • (String)


3518
3519
3520
# File 'lib/google/apis/logging_v2/classes.rb', line 3518

def request_id
  @request_id
end

#resourceString

Contains the path and query portion of the URL that was requested. For example, if the URL was "http://example.com/app?name=val", the resource would be "/app? name=val". The fragment identifier, which is identified by the # character, is not included. Corresponds to the JSON property resource

Returns:

  • (String)


3526
3527
3528
# File 'lib/google/apis/logging_v2/classes.rb', line 3526

def resource
  @resource
end

#response_sizeFixnum

Size in bytes sent back to client by request. Corresponds to the JSON property responseSize

Returns:

  • (Fixnum)


3531
3532
3533
# File 'lib/google/apis/logging_v2/classes.rb', line 3531

def response_size
  @response_size
end

#source_referenceArray<Google::Apis::LoggingV2::SourceReference>

Source code for the application that handled this request. There can be more than one source reference per deployed application if source code is distributed among multiple repositories. Corresponds to the JSON property sourceReference



3538
3539
3540
# File 'lib/google/apis/logging_v2/classes.rb', line 3538

def source_reference
  @source_reference
end

#span_idString

Stackdriver Trace span identifier for this request. Corresponds to the JSON property spanId

Returns:

  • (String)


3543
3544
3545
# File 'lib/google/apis/logging_v2/classes.rb', line 3543

def span_id
  @span_id
end

#start_timeString

Time when the request started. Corresponds to the JSON property startTime

Returns:

  • (String)


3548
3549
3550
# File 'lib/google/apis/logging_v2/classes.rb', line 3548

def start_time
  @start_time
end

#statusFixnum

HTTP response status code. Example: 200, 404. Corresponds to the JSON property status

Returns:

  • (Fixnum)


3553
3554
3555
# File 'lib/google/apis/logging_v2/classes.rb', line 3553

def status
  @status
end

#task_nameString

Task name of the request, in the case of an offline request. Corresponds to the JSON property taskName

Returns:

  • (String)


3558
3559
3560
# File 'lib/google/apis/logging_v2/classes.rb', line 3558

def task_name
  @task_name
end

#task_queue_nameString

Queue name of the request, in the case of an offline request. Corresponds to the JSON property taskQueueName

Returns:

  • (String)


3563
3564
3565
# File 'lib/google/apis/logging_v2/classes.rb', line 3563

def task_queue_name
  @task_queue_name
end

#trace_idString

Stackdriver Trace identifier for this request. Corresponds to the JSON property traceId

Returns:

  • (String)


3568
3569
3570
# File 'lib/google/apis/logging_v2/classes.rb', line 3568

def trace_id
  @trace_id
end

#trace_sampledBoolean Also known as: trace_sampled?

If true, the value in the 'trace_id' field was sampled for storage in a trace backend. Corresponds to the JSON property traceSampled

Returns:

  • (Boolean)


3574
3575
3576
# File 'lib/google/apis/logging_v2/classes.rb', line 3574

def trace_sampled
  @trace_sampled
end

#url_map_entryString

File or class that handled the request. Corresponds to the JSON property urlMapEntry

Returns:

  • (String)


3580
3581
3582
# File 'lib/google/apis/logging_v2/classes.rb', line 3580

def url_map_entry
  @url_map_entry
end

#user_agentString

User agent that made the request. Corresponds to the JSON property userAgent

Returns:

  • (String)


3585
3586
3587
# File 'lib/google/apis/logging_v2/classes.rb', line 3585

def user_agent
  @user_agent
end

#version_idString

Version of the application that handled this request. Corresponds to the JSON property versionId

Returns:

  • (String)


3590
3591
3592
# File 'lib/google/apis/logging_v2/classes.rb', line 3590

def version_id
  @version_id
end

#was_loading_requestBoolean Also known as: was_loading_request?

Whether this was a loading request for the instance. Corresponds to the JSON property wasLoadingRequest

Returns:

  • (Boolean)


3595
3596
3597
# File 'lib/google/apis/logging_v2/classes.rb', line 3595

def was_loading_request
  @was_loading_request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
3624
3625
3626
3627
3628
3629
3630
3631
3632
3633
3634
3635
3636
3637
3638
# File 'lib/google/apis/logging_v2/classes.rb', line 3603

def update!(**args)
  @app_engine_release = args[:app_engine_release] if args.key?(:app_engine_release)
  @app_id = args[:app_id] if args.key?(:app_id)
  @cost = args[:cost] if args.key?(:cost)
  @end_time = args[:end_time] if args.key?(:end_time)
  @finished = args[:finished] if args.key?(:finished)
  @first = args[:first] if args.key?(:first)
  @host = args[:host] if args.key?(:host)
  @http_version = args[:http_version] if args.key?(:http_version)
  @instance_id = args[:instance_id] if args.key?(:instance_id)
  @instance_index = args[:instance_index] if args.key?(:instance_index)
  @ip = args[:ip] if args.key?(:ip)
  @latency = args[:latency] if args.key?(:latency)
  @line = args[:line] if args.key?(:line)
  @mega_cycles = args[:mega_cycles] if args.key?(:mega_cycles)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @module_id = args[:module_id] if args.key?(:module_id)
  @nickname = args[:nickname] if args.key?(:nickname)
  @pending_time = args[:pending_time] if args.key?(:pending_time)
  @referrer = args[:referrer] if args.key?(:referrer)
  @request_id = args[:request_id] if args.key?(:request_id)
  @resource = args[:resource] if args.key?(:resource)
  @response_size = args[:response_size] if args.key?(:response_size)
  @source_reference = args[:source_reference] if args.key?(:source_reference)
  @span_id = args[:span_id] if args.key?(:span_id)
  @start_time = args[:start_time] if args.key?(:start_time)
  @status = args[:status] if args.key?(:status)
  @task_name = args[:task_name] if args.key?(:task_name)
  @task_queue_name = args[:task_queue_name] if args.key?(:task_queue_name)
  @trace_id = args[:trace_id] if args.key?(:trace_id)
  @trace_sampled = args[:trace_sampled] if args.key?(:trace_sampled)
  @url_map_entry = args[:url_map_entry] if args.key?(:url_map_entry)
  @user_agent = args[:user_agent] if args.key?(:user_agent)
  @version_id = args[:version_id] if args.key?(:version_id)
  @was_loading_request = args[:was_loading_request] if args.key?(:was_loading_request)
end