Class: Google::Apis::LoggingV2::SavedQuery
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::SavedQuery
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Describes a query that has been saved by a user.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#logging_query ⇒ Google::Apis::LoggingV2::LoggingQuery
Describes a Cloud Logging query that can be run in Logs Explorer UI or via the logging API.In addition to the query itself, additional information may be stored to capture the display configuration and other UI state used in association with analysis of query results.
-
#name ⇒ String
Output only.
-
#ops_analytics_query ⇒ Google::Apis::LoggingV2::OpsAnalyticsQuery
Describes a query that can be run in Log Analytics.
-
#update_time ⇒ String
Output only.
-
#visibility ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SavedQuery
constructor
A new instance of SavedQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SavedQuery
Returns a new instance of SavedQuery.
4076 4077 4078 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4076 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the saved query was created.
Corresponds to the JSON property createTime
4031 4032 4033 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4031 def create_time @create_time end |
#description ⇒ String
Optional. A human readable description of the saved query.
Corresponds to the JSON property description
4036 4037 4038 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4036 def description @description end |
#display_name ⇒ String
Required. The user specified title for the SavedQuery.
Corresponds to the JSON property displayName
4041 4042 4043 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4041 def display_name @display_name end |
#logging_query ⇒ Google::Apis::LoggingV2::LoggingQuery
Describes a Cloud Logging query that can be run in Logs Explorer UI or via the
logging API.In addition to the query itself, additional information may be
stored to capture the display configuration and other UI state used in
association with analysis of query results.
Corresponds to the JSON property loggingQuery
4049 4050 4051 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4049 def logging_query @logging_query end |
#name ⇒ String
Output only. Resource name of the saved query.In the format: "projects/[
PROJECT_ID]/locations/[LOCATION_ID]/savedQueries/[QUERY_ID]" For a list of
supported locations, see Supported Regions (https://docs.cloud.google.com/
logging/docs/region-support#bucket-regions)After the saved query is created,
the location cannot be changed.If the user doesn't provide a QUERY_ID, the
system will generate an alphanumeric ID.
Corresponds to the JSON property name
4059 4060 4061 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4059 def name @name end |
#ops_analytics_query ⇒ Google::Apis::LoggingV2::OpsAnalyticsQuery
Describes a query that can be run in Log Analytics.
Corresponds to the JSON property opsAnalyticsQuery
4064 4065 4066 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4064 def ops_analytics_query @ops_analytics_query end |
#update_time ⇒ String
Output only. The timestamp when the saved query was last updated.
Corresponds to the JSON property updateTime
4069 4070 4071 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4069 def update_time @update_time end |
#visibility ⇒ String
Required. The visibility status of this query, which determines its ownership.
Corresponds to the JSON property visibility
4074 4075 4076 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4074 def visibility @visibility end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4081 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @logging_query = args[:logging_query] if args.key?(:logging_query) @name = args[:name] if args.key?(:name) @ops_analytics_query = args[:ops_analytics_query] if args.key?(:ops_analytics_query) @update_time = args[:update_time] if args.key?(:update_time) @visibility = args[:visibility] if args.key?(:visibility) end |