Class: Google::Apis::LoggingV2::SavedQuery

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Describes a query that has been saved by a user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SavedQuery

Returns a new instance of SavedQuery.



4051
4052
4053
# File 'lib/google/apis/logging_v2/classes.rb', line 4051

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the saved query was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4006
4007
4008
# File 'lib/google/apis/logging_v2/classes.rb', line 4006

def create_time
  @create_time
end

#descriptionString

Optional. A human readable description of the saved query. Corresponds to the JSON property description

Returns:

  • (String)


4011
4012
4013
# File 'lib/google/apis/logging_v2/classes.rb', line 4011

def description
  @description
end

#display_nameString

Required. The user specified title for the SavedQuery. Corresponds to the JSON property displayName

Returns:

  • (String)


4016
4017
4018
# File 'lib/google/apis/logging_v2/classes.rb', line 4016

def display_name
  @display_name
end

#logging_queryGoogle::Apis::LoggingV2::LoggingQuery

Describes a Cloud Logging query that can be run in Logs Explorer UI or via the logging API.In addition to the query itself, additional information may be stored to capture the display configuration and other UI state used in association with analysis of query results. Corresponds to the JSON property loggingQuery



4024
4025
4026
# File 'lib/google/apis/logging_v2/classes.rb', line 4024

def logging_query
  @logging_query
end

#nameString

Output only. Resource name of the saved query.In the format: "projects/[ PROJECT_ID]/locations/[LOCATION_ID]/savedQueries/[QUERY_ID]" For a list of supported locations, see Supported Regions (https://docs.cloud.google.com/ logging/docs/region-support#bucket-regions)After the saved query is created, the location cannot be changed.If the user doesn't provide a QUERY_ID, the system will generate an alphanumeric ID. Corresponds to the JSON property name

Returns:

  • (String)


4034
4035
4036
# File 'lib/google/apis/logging_v2/classes.rb', line 4034

def name
  @name
end

#ops_analytics_queryGoogle::Apis::LoggingV2::OpsAnalyticsQuery

Describes a query that can be run in Log Analytics. Corresponds to the JSON property opsAnalyticsQuery



4039
4040
4041
# File 'lib/google/apis/logging_v2/classes.rb', line 4039

def ops_analytics_query
  @ops_analytics_query
end

#update_timeString

Output only. The timestamp when the saved query was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4044
4045
4046
# File 'lib/google/apis/logging_v2/classes.rb', line 4044

def update_time
  @update_time
end

#visibilityString

Required. The visibility status of this query, which determines its ownership. Corresponds to the JSON property visibility

Returns:

  • (String)


4049
4050
4051
# File 'lib/google/apis/logging_v2/classes.rb', line 4049

def visibility
  @visibility
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
# File 'lib/google/apis/logging_v2/classes.rb', line 4056

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @logging_query = args[:logging_query] if args.key?(:logging_query)
  @name = args[:name] if args.key?(:name)
  @ops_analytics_query = args[:ops_analytics_query] if args.key?(:ops_analytics_query)
  @update_time = args[:update_time] if args.key?(:update_time)
  @visibility = args[:visibility] if args.key?(:visibility)
end