Class: Google::Apis::LoggingV2::SortOrderParameter
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::SortOrderParameter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
A sort order for a query based on a column.
Instance Attribute Summary collapse
-
#field_source ⇒ Google::Apis::LoggingV2::FieldSource
A source that can be used to represent a "field of data" within various parts of a structured query, such as in SELECT, WHERE, or ORDER BY clauses.
-
#sort_order_direction ⇒ String
The sort order to use for the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SortOrderParameter
constructor
A new instance of SortOrderParameter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SortOrderParameter
Returns a new instance of SortOrderParameter.
4238 4239 4240 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4238 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_source ⇒ Google::Apis::LoggingV2::FieldSource
A source that can be used to represent a "field of data" within various parts
of a structured query, such as in SELECT, WHERE, or ORDER BY clauses. The term
"field of data" is used here because it is not limited to literal fields in
the underlying data schema.
Corresponds to the JSON property fieldSource
4231 4232 4233 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4231 def field_source @field_source end |
#sort_order_direction ⇒ String
The sort order to use for the query.
Corresponds to the JSON property sortOrderDirection
4236 4237 4238 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4236 def sort_order_direction @sort_order_direction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4243 4244 4245 4246 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4243 def update!(**args) @field_source = args[:field_source] if args.key?(:field_source) @sort_order_direction = args[:sort_order_direction] if args.key?(:sort_order_direction) end |