Class: Google::Apis::LoggingV2::SourceLocation
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::SourceLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Specifies a location in a source code file.
Instance Attribute Summary collapse
-
#file ⇒ String
Source file name.
-
#function_name ⇒ String
Human-readable name of the function or method being invoked, with optional context such as the class or package name.
-
#line ⇒ Fixnum
Line within the source file.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SourceLocation
constructor
A new instance of SourceLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SourceLocation
Returns a new instance of SourceLocation.
4248 4249 4250 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4248 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file ⇒ String
Source file name. Depending on the runtime environment, this might be a simple
name or a fully-qualified name.
Corresponds to the JSON property file
4232 4233 4234 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4232 def file @file end |
#function_name ⇒ String
Human-readable name of the function or method being invoked, with optional
context such as the class or package name. This information is used in
contexts such as the logs viewer, where a file and line number are less
meaningful. The format can vary by language. For example: qual.if.ied.Class.
method (Java), dir/package.func (Go), function (Python).
Corresponds to the JSON property functionName
4241 4242 4243 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4241 def function_name @function_name end |
#line ⇒ Fixnum
Line within the source file.
Corresponds to the JSON property line
4246 4247 4248 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4246 def line @line end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4253 4254 4255 4256 4257 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4253 def update!(**args) @file = args[:file] if args.key?(:file) @function_name = args[:function_name] if args.key?(:function_name) @line = args[:line] if args.key?(:line) end |