Class: Google::Apis::LoggingV2::SourceLocation
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::SourceLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Specifies a location in a source code file.
Instance Attribute Summary collapse
-
#file ⇒ String
Source file name.
-
#function_name ⇒ String
Human-readable name of the function or method being invoked, with optional context such as the class or package name.
-
#line ⇒ Fixnum
Line within the source file.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SourceLocation
constructor
A new instance of SourceLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SourceLocation
Returns a new instance of SourceLocation.
3872 3873 3874 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3872 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file ⇒ String
Source file name. Depending on the runtime environment, this might be a simple
name or a fully-qualified name.
Corresponds to the JSON property file
3856 3857 3858 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3856 def file @file end |
#function_name ⇒ String
Human-readable name of the function or method being invoked, with optional
context such as the class or package name. This information is used in
contexts such as the logs viewer, where a file and line number are less
meaningful. The format can vary by language. For example: qual.if.ied.Class.
method (Java), dir/package.func (Go), function (Python).
Corresponds to the JSON property functionName
3865 3866 3867 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3865 def function_name @function_name end |
#line ⇒ Fixnum
Line within the source file.
Corresponds to the JSON property line
3870 3871 3872 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3870 def line @line end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3877 3878 3879 3880 3881 |
# File 'lib/google/apis/logging_v2/classes.rb', line 3877 def update!(**args) @file = args[:file] if args.key?(:file) @function_name = args[:function_name] if args.key?(:function_name) @line = args[:line] if args.key?(:line) end |