Class: Google::Apis::LoggingV2::SuppressionInfo
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::SuppressionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Information about entries that were omitted from the session.
Instance Attribute Summary collapse
-
#reason ⇒ String
The reason that entries were omitted from the session.
-
#suppressed_count ⇒ Fixnum
A lower bound on the count of entries omitted due to reason.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SuppressionInfo
constructor
A new instance of SuppressionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SuppressionInfo
Returns a new instance of SuppressionInfo.
4369 4370 4371 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4369 def initialize(**args) update!(**args) end |
Instance Attribute Details
#reason ⇒ String
The reason that entries were omitted from the session.
Corresponds to the JSON property reason
4362 4363 4364 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4362 def reason @reason end |
#suppressed_count ⇒ Fixnum
A lower bound on the count of entries omitted due to reason.
Corresponds to the JSON property suppressedCount
4367 4368 4369 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4367 def suppressed_count @suppressed_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4374 4375 4376 4377 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4374 def update!(**args) @reason = args[:reason] if args.key?(:reason) @suppressed_count = args[:suppressed_count] if args.key?(:suppressed_count) end |