Class: Google::Apis::LoggingV2::SuppressionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Information about entries that were omitted from the session.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SuppressionInfo

Returns a new instance of SuppressionInfo.



4363
4364
4365
# File 'lib/google/apis/logging_v2/classes.rb', line 4363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#reasonString

The reason that entries were omitted from the session. Corresponds to the JSON property reason

Returns:

  • (String)


4356
4357
4358
# File 'lib/google/apis/logging_v2/classes.rb', line 4356

def reason
  @reason
end

#suppressed_countFixnum

A lower bound on the count of entries omitted due to reason. Corresponds to the JSON property suppressedCount

Returns:

  • (Fixnum)


4361
4362
4363
# File 'lib/google/apis/logging_v2/classes.rb', line 4361

def suppressed_count
  @suppressed_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4368
4369
4370
4371
# File 'lib/google/apis/logging_v2/classes.rb', line 4368

def update!(**args)
  @reason = args[:reason] if args.key?(:reason)
  @suppressed_count = args[:suppressed_count] if args.key?(:suppressed_count)
end