Class: Google::Apis::LoggingV2::SuppressionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Information about entries that were omitted from the session.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SuppressionInfo

Returns a new instance of SuppressionInfo.



3987
3988
3989
# File 'lib/google/apis/logging_v2/classes.rb', line 3987

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#reasonString

The reason that entries were omitted from the session. Corresponds to the JSON property reason

Returns:

  • (String)


3980
3981
3982
# File 'lib/google/apis/logging_v2/classes.rb', line 3980

def reason
  @reason
end

#suppressed_countFixnum

A lower bound on the count of entries omitted due to reason. Corresponds to the JSON property suppressedCount

Returns:

  • (Fixnum)


3985
3986
3987
# File 'lib/google/apis/logging_v2/classes.rb', line 3985

def suppressed_count
  @suppressed_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3992
3993
3994
3995
# File 'lib/google/apis/logging_v2/classes.rb', line 3992

def update!(**args)
  @reason = args[:reason] if args.key?(:reason)
  @suppressed_count = args[:suppressed_count] if args.key?(:suppressed_count)
end