Class: Google::Apis::LoggingV2::TailLogEntriesRequest
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::TailLogEntriesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
The parameters to TailLogEntries.
Instance Attribute Summary collapse
-
#buffer_window ⇒ String
Optional.
-
#filter ⇒ String
Optional.
-
#resource_names ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TailLogEntriesRequest
constructor
A new instance of TailLogEntriesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TailLogEntriesRequest
Returns a new instance of TailLogEntriesRequest.
4441 4442 4443 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4441 def initialize(**args) update!(**args) end |
Instance Attribute Details
#buffer_window ⇒ String
Optional. The amount of time to buffer log entries at the server before being
returned to prevent out of order results due to late arriving log entries.
Valid values are between 0-60000 milliseconds. Defaults to 2000 milliseconds.
Corresponds to the JSON property bufferWindow
4416 4417 4418 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4416 def buffer_window @buffer_window end |
#filter ⇒ String
Optional. A filter that chooses which log entries to return. For more
information, see Logging query language (https://docs.cloud.google.com/logging/
docs/view/logging-query-language).Only log entries that match the filter are
returned. An empty filter matches all log entries in the resources listed in
resource_names. Referencing a parent resource that is not listed in
resource_names will cause the filter to return no results. The maximum length
of a filter is 20,000 characters.
Corresponds to the JSON property filter
4427 4428 4429 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4427 def filter @filter end |
#resource_names ⇒ Array<String>
Required. Name of a parent resource from which to retrieve log entries:
projects/[PROJECT_ID] organizations/[ORGANIZATION_ID] billingAccounts/[
BILLING_ACCOUNT_ID] folders/[FOLDER_ID]May alternatively be one or more views:
projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[
VIEW_ID] organizations/[ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[
BUCKET_ID]/views/[VIEW_ID] billingAccounts/[BILLING_ACCOUNT_ID]/locations/[
LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID] folders/[FOLDER_ID]/locations/
[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]
Corresponds to the JSON property resourceNames
4439 4440 4441 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4439 def resource_names @resource_names end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4446 4447 4448 4449 4450 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4446 def update!(**args) @buffer_window = args[:buffer_window] if args.key?(:buffer_window) @filter = args[:filter] if args.key?(:filter) @resource_names = args[:resource_names] if args.key?(:resource_names) end |