Class: Google::Apis::LoggingV2::TailLogEntriesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb

Overview

Result returned from TailLogEntries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TailLogEntriesResponse

Returns a new instance of TailLogEntriesResponse.



4465
4466
4467
# File 'lib/google/apis/logging_v2/classes.rb', line 4465

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entriesArray<Google::Apis::LoggingV2::LogEntry>

A list of log entries. Each response in the stream will order entries with increasing values of LogEntry.timestamp. Ordering is not guaranteed between separate responses. Corresponds to the JSON property entries



4454
4455
4456
# File 'lib/google/apis/logging_v2/classes.rb', line 4454

def entries
  @entries
end

#suppression_infoArray<Google::Apis::LoggingV2::SuppressionInfo>

If entries that otherwise would have been included in the session were not sent back to the client, counts of relevant entries omitted from the session with the reason that they were not included. There will be at most one of each reason per response. The counts represent the number of suppressed entries since the last streamed response. Corresponds to the JSON property suppressionInfo



4463
4464
4465
# File 'lib/google/apis/logging_v2/classes.rb', line 4463

def suppression_info
  @suppression_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4470
4471
4472
4473
# File 'lib/google/apis/logging_v2/classes.rb', line 4470

def update!(**args)
  @entries = args[:entries] if args.key?(:entries)
  @suppression_info = args[:suppression_info] if args.key?(:suppression_info)
end