Class: Google::Apis::LoggingV2::TailLogEntriesResponse
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::TailLogEntriesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
Result returned from TailLogEntries.
Instance Attribute Summary collapse
-
#entries ⇒ Array<Google::Apis::LoggingV2::LogEntry>
A list of log entries.
-
#suppression_info ⇒ Array<Google::Apis::LoggingV2::SuppressionInfo>
If entries that otherwise would have been included in the session were not sent back to the client, counts of relevant entries omitted from the session with the reason that they were not included.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TailLogEntriesResponse
constructor
A new instance of TailLogEntriesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TailLogEntriesResponse
Returns a new instance of TailLogEntriesResponse.
4064 4065 4066 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4064 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entries ⇒ Array<Google::Apis::LoggingV2::LogEntry>
A list of log entries. Each response in the stream will order entries with
increasing values of LogEntry.timestamp. Ordering is not guaranteed between
separate responses.
Corresponds to the JSON property entries
4053 4054 4055 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4053 def entries @entries end |
#suppression_info ⇒ Array<Google::Apis::LoggingV2::SuppressionInfo>
If entries that otherwise would have been included in the session were not
sent back to the client, counts of relevant entries omitted from the session
with the reason that they were not included. There will be at most one of each
reason per response. The counts represent the number of suppressed entries
since the last streamed response.
Corresponds to the JSON property suppressionInfo
4062 4063 4064 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4062 def suppression_info @suppression_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4069 4070 4071 4072 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4069 def update!(**args) @entries = args[:entries] if args.key?(:entries) @suppression_info = args[:suppression_info] if args.key?(:suppression_info) end |