Class: Google::Apis::LoggingV2::VirtualField
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2::VirtualField
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/logging_v2/classes.rb,
lib/google/apis/logging_v2/representations.rb,
lib/google/apis/logging_v2/representations.rb
Overview
A virtual field is a field that is not physically present in the underlying data schema, but is created through specific operations within the query builder model based on other fields in the schema.
Instance Attribute Summary collapse
-
#underlying_field_sources ⇒ Array<Google::Apis::LoggingV2::FieldSource>
The field sources that will be used to create the virtual field, based on the semantics of the virtual field type.The field sources must follow these rules, based on the virtual field type: - For VIRTUAL_FIELD_TYPE_UNSPECIFIED, this field must be empty.
-
#virtual_field_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VirtualField
constructor
A new instance of VirtualField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VirtualField
Returns a new instance of VirtualField.
4602 4603 4604 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4602 def initialize(**args) update!(**args) end |
Instance Attribute Details
#underlying_field_sources ⇒ Array<Google::Apis::LoggingV2::FieldSource>
The field sources that will be used to create the virtual field, based on the
semantics of the virtual field type.The field sources must follow these rules,
based on the virtual field type: - For VIRTUAL_FIELD_TYPE_UNSPECIFIED, this
field must be empty. - For COALESCE, this field must be non-empty and include
a minimum of two field sources. The underlying field sources must be actual
projected fields that represent actual schema fields and that must not be
transformed and aggregated in any way, except for casting. The type of all the
underlying field sources must be equivalent so that picking one of them would
result in the same value type.
Corresponds to the JSON property underlyingFieldSources
4595 4596 4597 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4595 def @underlying_field_sources end |
#virtual_field_type ⇒ String
Required. The type of the virtual field.
Corresponds to the JSON property virtualFieldType
4600 4601 4602 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4600 def virtual_field_type @virtual_field_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4607 4608 4609 4610 |
# File 'lib/google/apis/logging_v2/classes.rb', line 4607 def update!(**args) @underlying_field_sources = args[:underlying_field_sources] if args.key?(:underlying_field_sources) @virtual_field_type = args[:virtual_field_type] if args.key?(:virtual_field_type) end |